#include "exim.h"
static macro_item p0 = { .next=NULL, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_HAVE_CRYPTEQ", .replacement=US"y" };
static macro_item p1 = { .next=&p0, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_HAVE_ICONV", .replacement=US"y" };
static macro_item p2 = { .next=&p1, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_IPV6", .replacement=US"y" };
static macro_item p3 = { .next=&p2, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_HAVE_PAM", .replacement=US"y" };
static macro_item p4 = { .next=&p3, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_HAVE_TLS", .replacement=US"y" };
static macro_item p5 = { .next=&p4, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_HAVE_OPENSSL", .replacement=US"y" };
static macro_item p6 = { .next=&p5, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_HAVE_CONTENT_SCANNING", .replacement=US"y" };
static macro_item p7 = { .next=&p6, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_DKIM", .replacement=US"y" };
static macro_item p8 = { .next=&p7, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_HAVE_DNSSEC", .replacement=US"y" };
static macro_item p9 = { .next=&p8, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_HAVE_ESMTP_LIMITS", .replacement=US"y" };
static macro_item p10 = { .next=&p9, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_HAVE_EVENT", .replacement=US"y" };
static macro_item p11 = { .next=&p10, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_I18N", .replacement=US"y" };
static macro_item p12 = { .next=&p11, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_OCSP", .replacement=US"y" };
static macro_item p13 = { .next=&p12, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_HAVE_PIPE_CONNECT", .replacement=US"y" };
static macro_item p14 = { .next=&p13, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_PRDR", .replacement=US"y" };
static macro_item p15 = { .next=&p14, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_HAVE_TCP_FASTOPEN", .replacement=US"y" };
static macro_item p16 = { .next=&p15, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_HAVE_SPF", .replacement=US"y" };
static macro_item p17 = { .next=&p16, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_HAVE_DANE", .replacement=US"y" };
static macro_item p18 = { .next=&p17, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_HAVE_TLS_RESUME", .replacement=US"y" };
static macro_item p19 = { .next=&p18, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_HAVE_WELLKNOWN", .replacement=US"y" };
static macro_item p20 = { .next=&p19, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_HAVE_HINTS_GDBM", .replacement=US"y" };
static macro_item p21 = { .next=&p20, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_HAVE_LOOKUP_LSEARCH", .replacement=US"y" };
static macro_item p22 = { .next=&p21, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_HAVE_LOOKUP_DBM", .replacement=US"y" };
static macro_item p23 = { .next=&p22, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_HAVE_LOOKUP_DNSDB", .replacement=US"y" };
static macro_item p24 = { .next=&p23, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_HAVE_LOOKUP_DSEARCH", .replacement=US"y" };
static macro_item p25 = { .next=&p24, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_HAVE_LOOKUP_JSON", .replacement=US"y" };
static macro_item p26 = { .next=&p25, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_HAVE_LOOKUP_LDAP", .replacement=US"y" };
static macro_item p27 = { .next=&p26, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_HAVE_LOOKUP_SQLITE", .replacement=US"y" };
static macro_item p28 = { .next=&p27, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_HAVE_TRANSPORT_APPEND_MAILDIR", .replacement=US"y" };
static macro_item p29 = { .next=&p28, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_ACL_COND_ACL", .replacement=US"y" };
static macro_item p30 = { .next=&p29, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_ACL_MOD_ADD_HEADER", .replacement=US"y" };
static macro_item p31 = { .next=&p30, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_ACL_COND_ATRN_DOMAINS", .replacement=US"y" };
static macro_item p32 = { .next=&p31, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_ACL_COND_AUTHENTICATED", .replacement=US"y" };
static macro_item p33 = { .next=&p32, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_ACL_COND_CONDITION", .replacement=US"y" };
static macro_item p34 = { .next=&p33, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_ACL_MOD_CONTINUE", .replacement=US"y" };
static macro_item p35 = { .next=&p34, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_MOD_CONTROL", .replacement=US"y" };
static macro_item p36 = { .next=&p35, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_COND_DECODE", .replacement=US"y" };
static macro_item p37 = { .next=&p36, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_ACL_MOD_DELAY", .replacement=US"y" };
static macro_item p38 = { .next=&p37, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_ACL_COND_DKIM_SIGNERS", .replacement=US"y" };
static macro_item p39 = { .next=&p38, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_ACL_COND_DKIM_STATUS", .replacement=US"y" };
static macro_item p40 = { .next=&p39, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_ACL_COND_DNSLISTS", .replacement=US"y" };
static macro_item p41 = { .next=&p40, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_ACL_COND_DOMAINS", .replacement=US"y" };
static macro_item p42 = { .next=&p41, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_ACL_COND_ENCRYPTED", .replacement=US"y" };
static macro_item p43 = { .next=&p42, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_MOD_ENDPASS", .replacement=US"y" };
static macro_item p44 = { .next=&p43, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_ACL_COND_HOSTS", .replacement=US"y" };
static macro_item p45 = { .next=&p44, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_ACL_COND_LOCAL_PARTS", .replacement=US"y" };
static macro_item p46 = { .next=&p45, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_ACL_MOD_LOG_MESSAGE", .replacement=US"y" };
static macro_item p47 = { .next=&p46, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_ACL_MOD_LOG_REJECT_TARGET", .replacement=US"y" };
static macro_item p48 = { .next=&p47, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_ACL_MOD_LOGWRITE", .replacement=US"y" };
static macro_item p49 = { .next=&p48, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_ACL_COND_MALWARE", .replacement=US"y" };
static macro_item p50 = { .next=&p49, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_MOD_MESSAGE", .replacement=US"y" };
static macro_item p51 = { .next=&p50, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_ACL_COND_MIME_REGEX", .replacement=US"y" };
static macro_item p52 = { .next=&p51, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_ACL_MOD_QUEUE", .replacement=US"y" };
static macro_item p53 = { .next=&p52, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_ACL_COND_RATELIMIT", .replacement=US"y" };
static macro_item p54 = { .next=&p53, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_ACL_COND_RECIPIENTS", .replacement=US"y" };
static macro_item p55 = { .next=&p54, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_ACL_COND_REGEX", .replacement=US"y" };
static macro_item p56 = { .next=&p55, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_ACL_MOD_REMOVE_HEADER", .replacement=US"y" };
static macro_item p57 = { .next=&p56, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_ACL_COND_SEEN", .replacement=US"y" };
static macro_item p58 = { .next=&p57, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_ACL_COND_SENDER_DOMAINS", .replacement=US"y" };
static macro_item p59 = { .next=&p58, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_ACL_COND_SENDERS", .replacement=US"y" };
static macro_item p60 = { .next=&p59, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_ACL_MOD_SET", .replacement=US"y" };
static macro_item p61 = { .next=&p60, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_ACL_COND_SPAM", .replacement=US"y" };
static macro_item p62 = { .next=&p61, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_ACL_COND_SPF", .replacement=US"y" };
static macro_item p63 = { .next=&p62, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_ACL_COND_SPF_GUESS", .replacement=US"y" };
static macro_item p64 = { .next=&p63, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_MOD_UDPSEND", .replacement=US"y" };
static macro_item p65 = { .next=&p64, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_ACL_COND_VERIFY", .replacement=US"y" };
static macro_item p66 = { .next=&p65, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_CRYPTO_SIGN_ED25519", .replacement=US"y" };
static macro_item p67 = { .next=&p66, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_CRYPTO_HASH_SHA3", .replacement=US"y" };
static macro_item p68 = { .next=&p67, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_HAVE_MALWARE_FPROTD", .replacement=US"y" };
static macro_item p69 = { .next=&p68, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_HAVE_MALWARE_FPROT6D", .replacement=US"y" };
static macro_item p70 = { .next=&p69, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_HAVE_MALWARE_DRWEB", .replacement=US"y" };
static macro_item p71 = { .next=&p70, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_HAVE_MALWARE_FSECURE", .replacement=US"y" };
static macro_item p72 = { .next=&p71, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_HAVE_MALWARE_SOPHIE", .replacement=US"y" };
static macro_item p73 = { .next=&p72, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_HAVE_MALWARE_CLAMD", .replacement=US"y" };
static macro_item p74 = { .next=&p73, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_HAVE_MALWARE_AVAST", .replacement=US"y" };
static macro_item p75 = { .next=&p74, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_HAVE_MALWARE_SOCK", .replacement=US"y" };
static macro_item p76 = { .next=&p75, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_HAVE_MALWARE_CMDLINE", .replacement=US"y" };
static macro_item p77 = { .next=&p76, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_ACCEPT_8BITMIME", .replacement=US"y" };
static macro_item p78 = { .next=&p77, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_ACL_NOT_SMTP", .replacement=US"y" };
static macro_item p79 = { .next=&p78, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_ACL_NOT_SMTP_MIME", .replacement=US"y" };
static macro_item p80 = { .next=&p79, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_ACL_NOT_SMTP_START", .replacement=US"y" };
static macro_item p81 = { .next=&p80, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_ATRN", .replacement=US"y" };
static macro_item p82 = { .next=&p81, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_AUTH", .replacement=US"y" };
static macro_item p83 = { .next=&p82, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_CONNECT", .replacement=US"y" };
static macro_item p84 = { .next=&p83, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_DATA", .replacement=US"y" };
static macro_item p85 = { .next=&p84, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_DATA_PRDR", .replacement=US"y" };
static macro_item p86 = { .next=&p85, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_DKIM", .replacement=US"y" };
static macro_item p87 = { .next=&p86, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_ETRN", .replacement=US"y" };
static macro_item p88 = { .next=&p87, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_EXPN", .replacement=US"y" };
static macro_item p89 = { .next=&p88, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_HELO", .replacement=US"y" };
static macro_item p90 = { .next=&p89, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_MAIL", .replacement=US"y" };
static macro_item p91 = { .next=&p90, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_MAILAUTH", .replacement=US"y" };
static macro_item p92 = { .next=&p91, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_MIME", .replacement=US"y" };
static macro_item p93 = { .next=&p92, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_NOTQUIT", .replacement=US"y" };
static macro_item p94 = { .next=&p93, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_PREDATA", .replacement=US"y" };
static macro_item p95 = { .next=&p94, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_QUIT", .replacement=US"y" };
static macro_item p96 = { .next=&p95, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_RCPT", .replacement=US"y" };
static macro_item p97 = { .next=&p96, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_STARTTLS", .replacement=US"y" };
static macro_item p98 = { .next=&p97, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_VRFY", .replacement=US"y" };
static macro_item p99 = { .next=&p98, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_ACL_SMTP_WELLKNOWN", .replacement=US"y" };
static macro_item p100 = { .next=&p99, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_ADD_ENVIRONMENT", .replacement=US"y" };
static macro_item p101 = { .next=&p100, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_ADMIN_GROUPS", .replacement=US"y" };
static macro_item p102 = { .next=&p101, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_ALLOW_DOMAIN_LITERALS", .replacement=US"y" };
static macro_item p103 = { .next=&p102, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_ALLOW_MX_TO_IP", .replacement=US"y" };
static macro_item p104 = { .next=&p103, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_ALLOW_UTF8_DOMAINS", .replacement=US"y" };
static macro_item p105 = { .next=&p104, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_AUTH_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p106 = { .next=&p105, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_AUTO_THAW", .replacement=US"y" };
static macro_item p107 = { .next=&p106, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_AV_SCANNER", .replacement=US"y" };
static macro_item p108 = { .next=&p107, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_BI_COMMAND", .replacement=US"y" };
static macro_item p109 = { .next=&p108, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_BOUNCE_MESSAGE_FILE", .replacement=US"y" };
static macro_item p110 = { .next=&p109, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_BOUNCE_MESSAGE_TEXT", .replacement=US"y" };
static macro_item p111 = { .next=&p110, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_BOUNCE_RETURN_BODY", .replacement=US"y" };
static macro_item p112 = { .next=&p111, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_MAIN_BOUNCE_RETURN_LINESIZE_LIMIT", .replacement=US"y" };
static macro_item p113 = { .next=&p112, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_BOUNCE_RETURN_MESSAGE", .replacement=US"y" };
static macro_item p114 = { .next=&p113, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_BOUNCE_RETURN_SIZE_LIMIT", .replacement=US"y" };
static macro_item p115 = { .next=&p114, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_MAIN_BOUNCE_SENDER_AUTHENTICATION", .replacement=US"y" };
static macro_item p116 = { .next=&p115, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_MAIN_CALLOUT_DOMAIN_NEGATIVE_EXPIRE", .replacement=US"y" };
static macro_item p117 = { .next=&p116, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_MAIN_CALLOUT_DOMAIN_POSITIVE_EXPIRE", .replacement=US"y" };
static macro_item p118 = { .next=&p117, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_CALLOUT_NEGATIVE_EXPIRE", .replacement=US"y" };
static macro_item p119 = { .next=&p118, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_CALLOUT_POSITIVE_EXPIRE", .replacement=US"y" };
static macro_item p120 = { .next=&p119, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_CALLOUT_RANDOM_LOCAL_PART", .replacement=US"y" };
static macro_item p121 = { .next=&p120, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_CHECK_LOG_INODES", .replacement=US"y" };
static macro_item p122 = { .next=&p121, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_CHECK_LOG_SPACE", .replacement=US"y" };
static macro_item p123 = { .next=&p122, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_CHECK_RFC2047_LENGTH", .replacement=US"y" };
static macro_item p124 = { .next=&p123, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_CHECK_SPOOL_INODES", .replacement=US"y" };
static macro_item p125 = { .next=&p124, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_CHECK_SPOOL_SPACE", .replacement=US"y" };
static macro_item p126 = { .next=&p125, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_CHUNKING_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p127 = { .next=&p126, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_MAIN_COMMANDLINE_CHECKS_REQUIRE_ADMIN", .replacement=US"y" };
static macro_item p128 = { .next=&p127, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_DAEMON_SMTP_PORT", .replacement=US"y" };
static macro_item p129 = { .next=&p128, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_DAEMON_SMTP_PORTS", .replacement=US"y" };
static macro_item p130 = { .next=&p129, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_DAEMON_STARTUP_RETRIES", .replacement=US"y" };
static macro_item p131 = { .next=&p130, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_DAEMON_STARTUP_SLEEP", .replacement=US"y" };
static macro_item p132 = { .next=&p131, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_DEBUG_STORE", .replacement=US"y" };
static macro_item p133 = { .next=&p132, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_DELAY_WARNING", .replacement=US"y" };
static macro_item p134 = { .next=&p133, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_DELAY_WARNING_CONDITION", .replacement=US"y" };
static macro_item p135 = { .next=&p134, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_DELIVER_DROP_PRIVILEGE", .replacement=US"y" };
static macro_item p136 = { .next=&p135, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_DELIVER_QUEUE_LOAD_MAX", .replacement=US"y" };
static macro_item p137 = { .next=&p136, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_DELIVERY_DATE_REMOVE", .replacement=US"y" };
static macro_item p138 = { .next=&p137, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_DISABLE_IPV6", .replacement=US"y" };
static macro_item p139 = { .next=&p138, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_DKIM_VERIFY_HASHES", .replacement=US"y" };
static macro_item p140 = { .next=&p139, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_DKIM_VERIFY_KEYTYPES", .replacement=US"y" };
static macro_item p141 = { .next=&p140, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_DKIM_VERIFY_MIN_KEYSIZES", .replacement=US"y" };
static macro_item p142 = { .next=&p141, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_DKIM_VERIFY_MINIMAL", .replacement=US"y" };
static macro_item p143 = { .next=&p142, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_DKIM_VERIFY_SIGNERS", .replacement=US"y" };
static macro_item p144 = { .next=&p143, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_DNS_AGAIN_MEANS_NONEXIST", .replacement=US"y" };
static macro_item p145 = { .next=&p144, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_DNS_CHECK_NAMES_PATTERN", .replacement=US"y" };
static macro_item p146 = { .next=&p145, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_DNS_CNAME_LOOPS", .replacement=US"y" };
static macro_item p147 = { .next=&p146, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_DNS_CSA_SEARCH_LIMIT", .replacement=US"y" };
static macro_item p148 = { .next=&p147, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_DNS_CSA_USE_REVERSE", .replacement=US"y" };
static macro_item p149 = { .next=&p148, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_DNS_DNSSEC_OK", .replacement=US"y" };
static macro_item p150 = { .next=&p149, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_DNS_IPV4_LOOKUP", .replacement=US"y" };
static macro_item p151 = { .next=&p150, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_DNS_RETRANS", .replacement=US"y" };
static macro_item p152 = { .next=&p151, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_DNS_RETRY", .replacement=US"y" };
static macro_item p153 = { .next=&p152, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_DNS_TRUST_AA", .replacement=US"y" };
static macro_item p154 = { .next=&p153, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_DNS_USE_EDNS0", .replacement=US"y" };
static macro_item p155 = { .next=&p154, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_MAIN_DROP_CR", .replacement=US"y" };
static macro_item p156 = { .next=&p155, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_DSN_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p157 = { .next=&p156, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_OPT_MAIN_DSN_FROM", .replacement=US"y" };
static macro_item p158 = { .next=&p157, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_ENVELOPE_TO_REMOVE", .replacement=US"y" };
static macro_item p159 = { .next=&p158, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_ERRORS_COPY", .replacement=US"y" };
static macro_item p160 = { .next=&p159, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_ERRORS_REPLY_TO", .replacement=US"y" };
static macro_item p161 = { .next=&p160, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_EVENT_ACTION", .replacement=US"y" };
static macro_item p162 = { .next=&p161, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_EXIM_GROUP", .replacement=US"y" };
static macro_item p163 = { .next=&p162, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_EXIM_PATH", .replacement=US"y" };
static macro_item p164 = { .next=&p163, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_EXIM_USER", .replacement=US"y" };
static macro_item p165 = { .next=&p164, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_EXIM_VERSION", .replacement=US"y" };
static macro_item p166 = { .next=&p165, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_EXTRA_LOCAL_INTERFACES", .replacement=US"y" };
static macro_item p167 = { .next=&p166, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_MAIN_EXTRACT_ADDRESSES_REMOVE_ARGUMENTS", .replacement=US"y" };
static macro_item p168 = { .next=&p167, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_FINDUSER_RETRIES", .replacement=US"y" };
static macro_item p169 = { .next=&p168, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_FREEZE_TELL", .replacement=US"y" };
static macro_item p170 = { .next=&p169, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_GECOS_NAME", .replacement=US"y" };
static macro_item p171 = { .next=&p170, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_GECOS_PATTERN", .replacement=US"y" };
static macro_item p172 = { .next=&p171, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_GNUTLS_ALLOW_AUTO_PKCS11", .replacement=US"y" };
static macro_item p173 = { .next=&p172, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_GNUTLS_COMPAT_MODE", .replacement=US"y" };
static macro_item p174 = { .next=&p173, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_HEADER_LINE_MAXSIZE", .replacement=US"y" };
static macro_item p175 = { .next=&p174, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_HEADER_MAXSIZE", .replacement=US"y" };
static macro_item p176 = { .next=&p175, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_HEADERS_CHARSET", .replacement=US"y" };
static macro_item p177 = { .next=&p176, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_HELO_ACCEPT_JUNK_HOSTS", .replacement=US"y" };
static macro_item p178 = { .next=&p177, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_HELO_ALLOW_CHARS", .replacement=US"y" };
static macro_item p179 = { .next=&p178, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_HELO_LOOKUP_DOMAINS", .replacement=US"y" };
static macro_item p180 = { .next=&p179, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_HELO_TRY_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p181 = { .next=&p180, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_HELO_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p182 = { .next=&p181, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_HOLD_DOMAINS", .replacement=US"y" };
static macro_item p183 = { .next=&p182, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_HOST_LOOKUP", .replacement=US"y" };
static macro_item p184 = { .next=&p183, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_HOST_LOOKUP_ORDER", .replacement=US"y" };
static macro_item p185 = { .next=&p184, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_HOST_REJECT_CONNECTION", .replacement=US"y" };
static macro_item p186 = { .next=&p185, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_HOSTS_CONNECTION_NOLOG", .replacement=US"y" };
static macro_item p187 = { .next=&p186, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_HOSTS_REQUIRE_ALPN", .replacement=US"y" };
static macro_item p188 = { .next=&p187, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_HOSTS_REQUIRE_HELO", .replacement=US"y" };
static macro_item p189 = { .next=&p188, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_HOSTS_TREAT_AS_LOCAL", .replacement=US"y" };
static macro_item p190 = { .next=&p189, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_MAIN_IGNORE_BOUNCE_ERRORS_AFTER", .replacement=US"y" };
static macro_item p191 = { .next=&p190, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_IGNORE_FROMLINE_HOSTS", .replacement=US"y" };
static macro_item p192 = { .next=&p191, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_IGNORE_FROMLINE_LOCAL", .replacement=US"y" };
static macro_item p193 = { .next=&p192, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_KEEP_ENVIRONMENT", .replacement=US"y" };
static macro_item p194 = { .next=&p193, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_KEEP_MALFORMED", .replacement=US"y" };
static macro_item p195 = { .next=&p194, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_LDAP_CA_CERT_DIR", .replacement=US"y" };
static macro_item p196 = { .next=&p195, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_LDAP_CA_CERT_FILE", .replacement=US"y" };
static macro_item p197 = { .next=&p196, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_LDAP_CERT_FILE", .replacement=US"y" };
static macro_item p198 = { .next=&p197, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_LDAP_CERT_KEY", .replacement=US"y" };
static macro_item p199 = { .next=&p198, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_LDAP_CIPHER_SUITE", .replacement=US"y" };
static macro_item p200 = { .next=&p199, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_LDAP_DEFAULT_SERVERS", .replacement=US"y" };
static macro_item p201 = { .next=&p200, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_LDAP_REQUIRE_CERT", .replacement=US"y" };
static macro_item p202 = { .next=&p201, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_LDAP_START_TLS", .replacement=US"y" };
static macro_item p203 = { .next=&p202, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_LDAP_VERSION", .replacement=US"y" };
static macro_item p204 = { .next=&p203, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_LIMITS_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p205 = { .next=&p204, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_LOCAL_FROM_CHECK", .replacement=US"y" };
static macro_item p206 = { .next=&p205, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_LOCAL_FROM_PREFIX", .replacement=US"y" };
static macro_item p207 = { .next=&p206, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_LOCAL_FROM_SUFFIX", .replacement=US"y" };
static macro_item p208 = { .next=&p207, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_LOCAL_INTERFACES", .replacement=US"y" };
static macro_item p209 = { .next=&p208, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_LOCAL_SENDER_RETAIN", .replacement=US"y" };
static macro_item p210 = { .next=&p209, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_LOCALHOST_NUMBER", .replacement=US"y" };
static macro_item p211 = { .next=&p210, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_LOG_FILE_PATH", .replacement=US"y" };
static macro_item p212 = { .next=&p211, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_LOG_PORTS", .replacement=US"y" };
static macro_item p213 = { .next=&p212, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_LOG_SELECTOR", .replacement=US"y" };
static macro_item p214 = { .next=&p213, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_LOG_TIMEZONE", .replacement=US"y" };
static macro_item p215 = { .next=&p214, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_LOOKUP_OPEN_MAX", .replacement=US"y" };
static macro_item p216 = { .next=&p215, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_MAX_USERNAME_LENGTH", .replacement=US"y" };
static macro_item p217 = { .next=&p216, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_MESSAGE_BODY_NEWLINES", .replacement=US"y" };
static macro_item p218 = { .next=&p217, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_MESSAGE_BODY_VISIBLE", .replacement=US"y" };
static macro_item p219 = { .next=&p218, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_MESSAGE_ID_HEADER_DOMAIN", .replacement=US"y" };
static macro_item p220 = { .next=&p219, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_MESSAGE_ID_HEADER_TEXT", .replacement=US"y" };
static macro_item p221 = { .next=&p220, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_MESSAGE_LOGS", .replacement=US"y" };
static macro_item p222 = { .next=&p221, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_MESSAGE_SIZE_LIMIT", .replacement=US"y" };
static macro_item p223 = { .next=&p222, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_MUA_WRAPPER", .replacement=US"y" };
static macro_item p224 = { .next=&p223, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_NEVER_USERS", .replacement=US"y" };
static macro_item p225 = { .next=&p224, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_NOTIFIER_SOCKET", .replacement=US"y" };
static macro_item p226 = { .next=&p225, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_OPENSSL_OPTIONS", .replacement=US"y" };
static macro_item p227 = { .next=&p226, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_PANIC_COREDUMP", .replacement=US"y" };
static macro_item p228 = { .next=&p227, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_PERCENT_HACK_DOMAINS", .replacement=US"y" };
static macro_item p229 = { .next=&p228, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_PID_FILE_PATH", .replacement=US"y" };
static macro_item p230 = { .next=&p229, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_MAIN_PIPELINING_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p231 = { .next=&p230, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_MAIN_PIPELINING_CONNECT_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p232 = { .next=&p231, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_PRDR_ENABLE", .replacement=US"y" };
static macro_item p233 = { .next=&p232, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_PRESERVE_MESSAGE_LOGS", .replacement=US"y" };
static macro_item p234 = { .next=&p233, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_PRIMARY_HOSTNAME", .replacement=US"y" };
static macro_item p235 = { .next=&p234, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_PRINT_TOPBITCHARS", .replacement=US"y" };
static macro_item p236 = { .next=&p235, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_PROCESS_LOG_PATH", .replacement=US"y" };
static macro_item p237 = { .next=&p236, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_PROD_REQUIRES_ADMIN", .replacement=US"y" };
static macro_item p238 = { .next=&p237, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_QUALIFY_DOMAIN", .replacement=US"y" };
static macro_item p239 = { .next=&p238, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_QUALIFY_RECIPIENT", .replacement=US"y" };
static macro_item p240 = { .next=&p239, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_QUEUE_DOMAINS", .replacement=US"y" };
static macro_item p241 = { .next=&p240, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_QUEUE_FAST_RAMP", .replacement=US"y" };
static macro_item p242 = { .next=&p241, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_QUEUE_LIST_REQUIRES_ADMIN", .replacement=US"y" };
static macro_item p243 = { .next=&p242, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_QUEUE_ONLY", .replacement=US"y" };
static macro_item p244 = { .next=&p243, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_QUEUE_ONLY_FILE", .replacement=US"y" };
static macro_item p245 = { .next=&p244, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_QUEUE_ONLY_LOAD", .replacement=US"y" };
static macro_item p246 = { .next=&p245, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_QUEUE_ONLY_LOAD_LATCH", .replacement=US"y" };
static macro_item p247 = { .next=&p246, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_QUEUE_ONLY_OVERRIDE", .replacement=US"y" };
static macro_item p248 = { .next=&p247, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_QUEUE_RUN_IN_ORDER", .replacement=US"y" };
static macro_item p249 = { .next=&p248, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_QUEUE_RUN_MAX", .replacement=US"y" };
static macro_item p250 = { .next=&p249, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_QUEUE_SMTP_DOMAINS", .replacement=US"y" };
static macro_item p251 = { .next=&p250, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_RECEIVE_TIMEOUT", .replacement=US"y" };
static macro_item p252 = { .next=&p251, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_RECEIVED_HEADER_TEXT", .replacement=US"y" };
static macro_item p253 = { .next=&p252, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_RECEIVED_HEADERS_MAX", .replacement=US"y" };
static macro_item p254 = { .next=&p253, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_MAIN_RECIPIENT_UNQUALIFIED_HOSTS", .replacement=US"y" };
static macro_item p255 = { .next=&p254, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_RECIPIENTS_MAX", .replacement=US"y" };
static macro_item p256 = { .next=&p255, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_RECIPIENTS_MAX_REJECT", .replacement=US"y" };
static macro_item p257 = { .next=&p256, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_REMOTE_MAX_PARALLEL", .replacement=US"y" };
static macro_item p258 = { .next=&p257, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_REMOTE_SORT_DOMAINS", .replacement=US"y" };
static macro_item p259 = { .next=&p258, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_RETRY_DATA_EXPIRE", .replacement=US"y" };
static macro_item p260 = { .next=&p259, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_RETRY_INTERVAL_MAX", .replacement=US"y" };
static macro_item p261 = { .next=&p260, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_RETURN_PATH_REMOVE", .replacement=US"y" };
static macro_item p262 = { .next=&p261, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_RETURN_SIZE_LIMIT", .replacement=US"y" };
static macro_item p263 = { .next=&p262, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_RFC1413_HOSTS", .replacement=US"y" };
static macro_item p264 = { .next=&p263, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_MAIN_RFC1413_PORT", .replacement=US"y" };
static macro_item p265 = { .next=&p264, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_RFC1413_QUERY_TIMEOUT", .replacement=US"y" };
static macro_item p266 = { .next=&p265, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_SENDER_UNQUALIFIED_HOSTS", .replacement=US"y" };
static macro_item p267 = { .next=&p266, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_SLOW_LOOKUP_LOG", .replacement=US"y" };
static macro_item p268 = { .next=&p267, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_KEEPALIVE", .replacement=US"y" };
static macro_item p269 = { .next=&p268, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_MAX", .replacement=US"y" };
static macro_item p270 = { .next=&p269, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_MAX_NONMAIL", .replacement=US"y" };
static macro_item p271 = { .next=&p270, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_MAX_NONMAIL_HOSTS", .replacement=US"y" };
static macro_item p272 = { .next=&p271, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_MAX_PER_CONNECTION", .replacement=US"y" };
static macro_item p273 = { .next=&p272, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_MAX_PER_HOST", .replacement=US"y" };
static macro_item p274 = { .next=&p273, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_QUEUE", .replacement=US"y" };
static macro_item p275 = { .next=&p274, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_QUEUE_PER_CONNECTION", .replacement=US"y" };
static macro_item p276 = { .next=&p275, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SMTP_ACCEPT_RESERVE", .replacement=US"y" };
static macro_item p277 = { .next=&p276, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_SMTP_ACTIVE_HOSTNAME", .replacement=US"y" };
static macro_item p278 = { .next=&p277, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_SMTP_BACKLOG_MONITOR", .replacement=US"y" };
static macro_item p279 = { .next=&p278, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_SMTP_BANNER", .replacement=US"y" };
static macro_item p280 = { .next=&p279, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_SMTP_CHECK_SPOOL_SPACE", .replacement=US"y" };
static macro_item p281 = { .next=&p280, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_SMTP_CONNECT_BACKLOG", .replacement=US"y" };
static macro_item p282 = { .next=&p281, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_SMTP_ENFORCE_SYNC", .replacement=US"y" };
static macro_item p283 = { .next=&p282, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_SMTP_ETRN_COMMAND", .replacement=US"y" };
static macro_item p284 = { .next=&p283, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SMTP_ETRN_SERIALIZE", .replacement=US"y" };
static macro_item p285 = { .next=&p284, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_SMTP_LOAD_RESERVE", .replacement=US"y" };
static macro_item p286 = { .next=&p285, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_SMTP_MAX_SYNPROT_ERRORS", .replacement=US"y" };
static macro_item p287 = { .next=&p286, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_SMTP_MAX_UNKNOWN_COMMANDS", .replacement=US"y" };
static macro_item p288 = { .next=&p287, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_SMTP_RATELIMIT_HOSTS", .replacement=US"y" };
static macro_item p289 = { .next=&p288, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SMTP_RATELIMIT_MAIL", .replacement=US"y" };
static macro_item p290 = { .next=&p289, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SMTP_RATELIMIT_RCPT", .replacement=US"y" };
static macro_item p291 = { .next=&p290, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_SMTP_RECEIVE_TIMEOUT", .replacement=US"y" };
static macro_item p292 = { .next=&p291, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_SMTP_RESERVE_HOSTS", .replacement=US"y" };
static macro_item p293 = { .next=&p292, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_SMTP_RETURN_ERROR_DETAILS", .replacement=US"y" };
static macro_item p294 = { .next=&p293, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_MAIN_SMTPUTF8_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p295 = { .next=&p294, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_SPAMD_ADDRESS", .replacement=US"y" };
static macro_item p296 = { .next=&p295, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_MAIN_SPF_GUESS", .replacement=US"y" };
static macro_item p297 = { .next=&p296, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_SPF_SMTP_COMMENT_TEMPLATE", .replacement=US"y" };
static macro_item p298 = { .next=&p297, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_MAIN_SPLIT_SPOOL_DIRECTORY", .replacement=US"y" };
static macro_item p299 = { .next=&p298, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_SPOOL_DIRECTORY", .replacement=US"y" };
static macro_item p300 = { .next=&p299, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_SPOOL_WIREFORMAT", .replacement=US"y" };
static macro_item p301 = { .next=&p300, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_SQLITE_DBFILE", .replacement=US"y" };
static macro_item p302 = { .next=&p301, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SQLITE_LOCK_TIMEOUT", .replacement=US"y" };
static macro_item p303 = { .next=&p302, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_STRICT_ACL_VARS", .replacement=US"y" };
static macro_item p304 = { .next=&p303, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_MAIN_STRIP_EXCESS_ANGLE_BRACKETS", .replacement=US"y" };
static macro_item p305 = { .next=&p304, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_STRIP_TRAILING_DOT", .replacement=US"y" };
static macro_item p306 = { .next=&p305, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_SYSLOG_DUPLICATION", .replacement=US"y" };
static macro_item p307 = { .next=&p306, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_SYSLOG_FACILITY", .replacement=US"y" };
static macro_item p308 = { .next=&p307, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_MAIN_SYSLOG_PID", .replacement=US"y" };
static macro_item p309 = { .next=&p308, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_SYSLOG_PROCESSNAME", .replacement=US"y" };
static macro_item p310 = { .next=&p309, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_SYSLOG_TIMESTAMP", .replacement=US"y" };
static macro_item p311 = { .next=&p310, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER", .replacement=US"y" };
static macro_item p312 = { .next=&p311, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_DIRECTORY_TRANSPORT", .replacement=US"y" };
static macro_item p313 = { .next=&p312, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_FILE_TRANSPORT", .replacement=US"y" };
static macro_item p314 = { .next=&p313, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_GROUP", .replacement=US"y" };
static macro_item p315 = { .next=&p314, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_PIPE_TRANSPORT", .replacement=US"y" };
static macro_item p316 = { .next=&p315, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_REPLY_TRANSPORT", .replacement=US"y" };
static macro_item p317 = { .next=&p316, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_SYSTEM_FILTER_USER", .replacement=US"y" };
static macro_item p318 = { .next=&p317, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_TCP_NODELAY", .replacement=US"y" };
static macro_item p319 = { .next=&p318, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_TIMEOUT_FROZEN_AFTER", .replacement=US"y" };
static macro_item p320 = { .next=&p319, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_OPT_MAIN_TIMEZONE", .replacement=US"y" };
static macro_item p321 = { .next=&p320, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_TLS_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p322 = { .next=&p321, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_OPT_MAIN_TLS_ALPN", .replacement=US"y" };
static macro_item p323 = { .next=&p322, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_TLS_CERTIFICATE", .replacement=US"y" };
static macro_item p324 = { .next=&p323, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_MAIN_TLS_CRL", .replacement=US"y" };
static macro_item p325 = { .next=&p324, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_TLS_DH_MAX_BITS", .replacement=US"y" };
static macro_item p326 = { .next=&p325, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_TLS_DHPARAM", .replacement=US"y" };
static macro_item p327 = { .next=&p326, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_MAIN_TLS_EARLY_BANNER_HOSTS", .replacement=US"y" };
static macro_item p328 = { .next=&p327, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_MAIN_TLS_ECCURVE", .replacement=US"y" };
static macro_item p329 = { .next=&p328, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_TLS_OCSP_FILE", .replacement=US"y" };
static macro_item p330 = { .next=&p329, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_TLS_ON_CONNECT_PORTS", .replacement=US"y" };
static macro_item p331 = { .next=&p330, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_TLS_PRIVATEKEY", .replacement=US"y" };
static macro_item p332 = { .next=&p331, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_MAIN_TLS_REMEMBER_ESMTP", .replacement=US"y" };
static macro_item p333 = { .next=&p332, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_MAIN_TLS_REQUIRE_CIPHERS", .replacement=US"y" };
static macro_item p334 = { .next=&p333, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_TLS_RESUMPTION_HOSTS", .replacement=US"y" };
static macro_item p335 = { .next=&p334, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_TLS_TRY_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p336 = { .next=&p335, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_MAIN_TLS_VERIFY_CERTIFICATES", .replacement=US"y" };
static macro_item p337 = { .next=&p336, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_TLS_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p338 = { .next=&p337, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_MAIN_TRUSTED_GROUPS", .replacement=US"y" };
static macro_item p339 = { .next=&p338, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_TRUSTED_USERS", .replacement=US"y" };
static macro_item p340 = { .next=&p339, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_MAIN_UNKNOWN_LOGIN", .replacement=US"y" };
static macro_item p341 = { .next=&p340, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_UNKNOWN_USERNAME", .replacement=US"y" };
static macro_item p342 = { .next=&p341, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_MAIN_UNTRUSTED_SET_SENDER", .replacement=US"y" };
static macro_item p343 = { .next=&p342, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_UUCP_FROM_PATTERN", .replacement=US"y" };
static macro_item p344 = { .next=&p343, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_MAIN_UUCP_FROM_SENDER", .replacement=US"y" };
static macro_item p345 = { .next=&p344, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_MAIN_WARN_MESSAGE_FILE", .replacement=US"y" };
static macro_item p346 = { .next=&p345, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_MAIN_WELLKNOWN_ADVERTISE_HOSTS", .replacement=US"y" };
static macro_item p347 = { .next=&p346, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_MAIN_WRITE_REJECTLOG", .replacement=US"y" };
static macro_item p348 = { .next=&p347, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_ROUTERS_ADDRESS_DATA", .replacement=US"y" };
static macro_item p349 = { .next=&p348, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_ROUTERS_ADDRESS_TEST", .replacement=US"y" };
static macro_item p350 = { .next=&p349, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_ROUTERS_CANNOT_ROUTE_MESSAGE", .replacement=US"y" };
static macro_item p351 = { .next=&p350, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTERS_CASEFUL_LOCAL_PART", .replacement=US"y" };
static macro_item p352 = { .next=&p351, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_ROUTERS_CHECK_LOCAL_USER", .replacement=US"y" };
static macro_item p353 = { .next=&p352, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_ROUTERS_CONDITION", .replacement=US"y" };
static macro_item p354 = { .next=&p353, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_DEBUG_PRINT", .replacement=US"y" };
static macro_item p355 = { .next=&p354, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_ROUTERS_DISABLE_LOGGING", .replacement=US"y" };
static macro_item p356 = { .next=&p355, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTERS_DNSSEC_REQUEST_DOMAINS", .replacement=US"y" };
static macro_item p357 = { .next=&p356, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTERS_DNSSEC_REQUIRE_DOMAINS", .replacement=US"y" };
static macro_item p358 = { .next=&p357, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_ROUTERS_DOMAINS", .replacement=US"y" };
static macro_item p359 = { .next=&p358, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_ROUTERS_DRIVER", .replacement=US"y" };
static macro_item p360 = { .next=&p359, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_DSN_LASTHOP", .replacement=US"y" };
static macro_item p361 = { .next=&p360, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_ROUTERS_ERRORS_TO", .replacement=US"y" };
static macro_item p362 = { .next=&p361, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_ROUTERS_EXPN", .replacement=US"y" };
static macro_item p363 = { .next=&p362, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_FAIL_VERIFY", .replacement=US"y" };
static macro_item p364 = { .next=&p363, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_ROUTERS_FAIL_VERIFY_RECIPIENT", .replacement=US"y" };
static macro_item p365 = { .next=&p364, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTERS_FAIL_VERIFY_SENDER", .replacement=US"y" };
static macro_item p366 = { .next=&p365, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_ROUTERS_FALLBACK_HOSTS", .replacement=US"y" };
static macro_item p367 = { .next=&p366, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_OPT_ROUTERS_GROUP", .replacement=US"y" };
static macro_item p368 = { .next=&p367, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_HEADERS_ADD", .replacement=US"y" };
static macro_item p369 = { .next=&p368, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_ROUTERS_HEADERS_REMOVE", .replacement=US"y" };
static macro_item p370 = { .next=&p369, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTERS_IGNORE_TARGET_HOSTS", .replacement=US"y" };
static macro_item p371 = { .next=&p370, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_ROUTERS_INITGROUPS", .replacement=US"y" };
static macro_item p372 = { .next=&p371, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_ROUTERS_LOCAL_PART_PREFIX", .replacement=US"y" };
static macro_item p373 = { .next=&p372, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTERS_LOCAL_PART_PREFIX_OPTIONAL", .replacement=US"y" };
static macro_item p374 = { .next=&p373, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_ROUTERS_LOCAL_PART_SUFFIX", .replacement=US"y" };
static macro_item p375 = { .next=&p374, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTERS_LOCAL_PART_SUFFIX_OPTIONAL", .replacement=US"y" };
static macro_item p376 = { .next=&p375, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_LOCAL_PARTS", .replacement=US"y" };
static macro_item p377 = { .next=&p376, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_ROUTERS_LOG_AS_LOCAL", .replacement=US"y" };
static macro_item p378 = { .next=&p377, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_ROUTERS_MORE", .replacement=US"y" };
static macro_item p379 = { .next=&p378, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_ROUTERS_PASS_ON_TIMEOUT", .replacement=US"y" };
static macro_item p380 = { .next=&p379, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_PASS_ROUTER", .replacement=US"y" };
static macro_item p381 = { .next=&p380, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_ROUTERS_REDIRECT_ROUTER", .replacement=US"y" };
static macro_item p382 = { .next=&p381, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_ROUTERS_REQUIRE_FILES", .replacement=US"y" };
static macro_item p383 = { .next=&p382, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_ROUTERS_RETRY_USE_LOCAL_PART", .replacement=US"y" };
static macro_item p384 = { .next=&p383, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_ROUTERS_ROUTER_HOME_DIRECTORY", .replacement=US"y" };
static macro_item p385 = { .next=&p384, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_ROUTERS_SELF", .replacement=US"y" };
static macro_item p386 = { .next=&p385, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_ROUTERS_SENDERS", .replacement=US"y" };
static macro_item p387 = { .next=&p386, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_OPT_ROUTERS_SET", .replacement=US"y" };
static macro_item p388 = { .next=&p387, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_ROUTERS_TRANSPORT", .replacement=US"y" };
static macro_item p389 = { .next=&p388, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTERS_TRANSPORT_CURRENT_DIRECTORY", .replacement=US"y" };
static macro_item p390 = { .next=&p389, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTERS_TRANSPORT_HOME_DIRECTORY", .replacement=US"y" };
static macro_item p391 = { .next=&p390, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_ROUTERS_UNSEEN", .replacement=US"y" };
static macro_item p392 = { .next=&p391, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_OPT_ROUTERS_USER", .replacement=US"y" };
static macro_item p393 = { .next=&p392, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_OPT_ROUTERS_VERIFY", .replacement=US"y" };
static macro_item p394 = { .next=&p393, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_ROUTERS_VERIFY_ONLY", .replacement=US"y" };
static macro_item p395 = { .next=&p394, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_ROUTERS_VERIFY_RECIPIENT", .replacement=US"y" };
static macro_item p396 = { .next=&p395, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_ROUTERS_VERIFY_SENDER", .replacement=US"y" };
static macro_item p397 = { .next=&p396, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_DRIVER_ROUTER_QUERYPROGRAM", .replacement=US"y" };
static macro_item p398 = { .next=&p397, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_QUERYPROGRAM_COMMAND", .replacement=US"y" };
static macro_item p399 = { .next=&p398, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_ROUTER_QUERYPROGRAM_COMMAND_GROUP", .replacement=US"y" };
static macro_item p400 = { .next=&p399, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_QUERYPROGRAM_COMMAND_USER", .replacement=US"y" };
static macro_item p401 = { .next=&p400, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_ROUTER_QUERYPROGRAM_CURRENT_DIRECTORY", .replacement=US"y" };
static macro_item p402 = { .next=&p401, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_QUERYPROGRAM_TIMEOUT", .replacement=US"y" };
static macro_item p403 = { .next=&p402, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_DRIVER_ROUTER_REDIRECT", .replacement=US"y" };
static macro_item p404 = { .next=&p403, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_ALLOW_DEFER", .replacement=US"y" };
static macro_item p405 = { .next=&p404, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_ALLOW_FAIL", .replacement=US"y" };
static macro_item p406 = { .next=&p405, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_ALLOW_FILTER", .replacement=US"y" };
static macro_item p407 = { .next=&p406, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_ALLOW_FREEZE", .replacement=US"y" };
static macro_item p408 = { .next=&p407, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_CHECK_ANCESTOR", .replacement=US"y" };
static macro_item p409 = { .next=&p408, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_CHECK_GROUP", .replacement=US"y" };
static macro_item p410 = { .next=&p409, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_CHECK_OWNER", .replacement=US"y" };
static macro_item p411 = { .next=&p410, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_DATA", .replacement=US"y" };
static macro_item p412 = { .next=&p411, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_DIRECTORY_TRANSPORT", .replacement=US"y" };
static macro_item p413 = { .next=&p412, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FILE", .replacement=US"y" };
static macro_item p414 = { .next=&p413, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FILE_TRANSPORT", .replacement=US"y" };
static macro_item p415 = { .next=&p414, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FILTER_PREPEND_HOME", .replacement=US"y" };
static macro_item p416 = { .next=&p415, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_BLACKHOLE", .replacement=US"y" };
static macro_item p417 = { .next=&p416, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_EXIM_FILTER", .replacement=US"y" };
static macro_item p418 = { .next=&p417, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILE", .replacement=US"y" };
static macro_item p419 = { .next=&p418, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_DLFUNC", .replacement=US"y" };
static macro_item p420 = { .next=&p419, .command_line=FALSE, .namelen=45, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_EXISTSTEST", .replacement=US"y" };
static macro_item p421 = { .next=&p420, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_LOGWRITE", .replacement=US"y" };
static macro_item p422 = { .next=&p421, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_LOOKUP", .replacement=US"y" };
static macro_item p423 = { .next=&p422, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_PERL", .replacement=US"y" };
static macro_item p424 = { .next=&p423, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_READFILE", .replacement=US"y" };
static macro_item p425 = { .next=&p424, .command_line=FALSE, .namelen=45, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_READSOCKET", .replacement=US"y" };
static macro_item p426 = { .next=&p425, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_REPLY", .replacement=US"y" };
static macro_item p427 = { .next=&p426, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_FILTER_RUN", .replacement=US"y" };
static macro_item p428 = { .next=&p427, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_INCLUDE", .replacement=US"y" };
static macro_item p429 = { .next=&p428, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_PIPE", .replacement=US"y" };
static macro_item p430 = { .next=&p429, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_SIEVE_FILTER", .replacement=US"y" };
static macro_item p431 = { .next=&p430, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_FORBID_SMTP_CODE", .replacement=US"y" };
static macro_item p432 = { .next=&p431, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_HIDE_CHILD_IN_ERRMSG", .replacement=US"y" };
static macro_item p433 = { .next=&p432, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_IGNORE_EACCES", .replacement=US"y" };
static macro_item p434 = { .next=&p433, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_IGNORE_ENOTDIR", .replacement=US"y" };
static macro_item p435 = { .next=&p434, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_INCLUDE_DIRECTORY", .replacement=US"y" };
static macro_item p436 = { .next=&p435, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_MODEMASK", .replacement=US"y" };
static macro_item p437 = { .next=&p436, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_ONE_TIME", .replacement=US"y" };
static macro_item p438 = { .next=&p437, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_OWNERS", .replacement=US"y" };
static macro_item p439 = { .next=&p438, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_OWNGROUPS", .replacement=US"y" };
static macro_item p440 = { .next=&p439, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_PIPE_TRANSPORT", .replacement=US"y" };
static macro_item p441 = { .next=&p440, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_QUALIFY_DOMAIN", .replacement=US"y" };
static macro_item p442 = { .next=&p441, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_QUALIFY_PRESERVE_DOMAIN", .replacement=US"y" };
static macro_item p443 = { .next=&p442, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_REPEAT_USE", .replacement=US"y" };
static macro_item p444 = { .next=&p443, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_REPLY_TRANSPORT", .replacement=US"y" };
static macro_item p445 = { .next=&p444, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_REWRITE", .replacement=US"y" };
static macro_item p446 = { .next=&p445, .command_line=FALSE, .namelen=47, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SIEVE_ENOTIFY_MAILTO_OWNER", .replacement=US"y" };
static macro_item p447 = { .next=&p446, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SIEVE_INBOX", .replacement=US"y" };
static macro_item p448 = { .next=&p447, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SIEVE_SUBADDRESS", .replacement=US"y" };
static macro_item p449 = { .next=&p448, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SIEVE_USERADDRESS", .replacement=US"y" };
static macro_item p450 = { .next=&p449, .command_line=FALSE, .namelen=45, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SIEVE_VACATION_DIRECTORY", .replacement=US"y" };
static macro_item p451 = { .next=&p450, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SKIP_SYNTAX_ERRORS", .replacement=US"y" };
static macro_item p452 = { .next=&p451, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SYNTAX_ERRORS_TEXT", .replacement=US"y" };
static macro_item p453 = { .next=&p452, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_REDIRECT_SYNTAX_ERRORS_TO", .replacement=US"y" };
static macro_item p454 = { .next=&p453, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_DRIVER_ROUTER_MANUALROUTE", .replacement=US"y" };
static macro_item p455 = { .next=&p454, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_HOST_ALL_IGNORED", .replacement=US"y" };
static macro_item p456 = { .next=&p455, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_HOST_FIND_FAILED", .replacement=US"y" };
static macro_item p457 = { .next=&p456, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_HOSTS_RANDOMIZE", .replacement=US"y" };
static macro_item p458 = { .next=&p457, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_ROUTE_DATA", .replacement=US"y" };
static macro_item p459 = { .next=&p458, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_ROUTE_LIST", .replacement=US"y" };
static macro_item p460 = { .next=&p459, .command_line=FALSE, .namelen=48, .replen=1, .name=US"_OPT_ROUTER_MANUALROUTE_SAME_DOMAIN_COPY_ROUTING", .replacement=US"y" };
static macro_item p461 = { .next=&p460, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_DRIVER_ROUTER_IPLITERAL", .replacement=US"y" };
static macro_item p462 = { .next=&p461, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_DRIVER_ROUTER_DNSLOOKUP", .replacement=US"y" };
static macro_item p463 = { .next=&p462, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_CHECK_SECONDARY_MX", .replacement=US"y" };
static macro_item p464 = { .next=&p463, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_CHECK_SRV", .replacement=US"y" };
static macro_item p465 = { .next=&p464, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_FAIL_DEFER_DOMAINS", .replacement=US"y" };
static macro_item p466 = { .next=&p465, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_IPV4_ONLY", .replacement=US"y" };
static macro_item p467 = { .next=&p466, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_IPV4_PREFER", .replacement=US"y" };
static macro_item p468 = { .next=&p467, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_MX_DOMAINS", .replacement=US"y" };
static macro_item p469 = { .next=&p468, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_MX_FAIL_DOMAINS", .replacement=US"y" };
static macro_item p470 = { .next=&p469, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_QUALIFY_SINGLE", .replacement=US"y" };
static macro_item p471 = { .next=&p470, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_REWRITE_HEADERS", .replacement=US"y" };
static macro_item p472 = { .next=&p471, .command_line=FALSE, .namelen=46, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_SAME_DOMAIN_COPY_ROUTING", .replacement=US"y" };
static macro_item p473 = { .next=&p472, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_SEARCH_PARENTS", .replacement=US"y" };
static macro_item p474 = { .next=&p473, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_SRV_FAIL_DOMAINS", .replacement=US"y" };
static macro_item p475 = { .next=&p474, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_ROUTER_DNSLOOKUP_WIDEN_DOMAINS", .replacement=US"y" };
static macro_item p476 = { .next=&p475, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_DRIVER_ROUTER_ACCEPT", .replacement=US"y" };
static macro_item p477 = { .next=&p476, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_TRANSPORTS_BODY_ONLY", .replacement=US"y" };
static macro_item p478 = { .next=&p477, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORTS_CURRENT_DIRECTORY", .replacement=US"y" };
static macro_item p479 = { .next=&p478, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORTS_DEBUG_PRINT", .replacement=US"y" };
static macro_item p480 = { .next=&p479, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORTS_DELIVERY_DATE_ADD", .replacement=US"y" };
static macro_item p481 = { .next=&p480, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORTS_DISABLE_LOGGING", .replacement=US"y" };
static macro_item p482 = { .next=&p481, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_OPT_TRANSPORTS_DRIVER", .replacement=US"y" };
static macro_item p483 = { .next=&p482, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORTS_ENVELOPE_TO_ADD", .replacement=US"y" };
static macro_item p484 = { .next=&p483, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORTS_EVENT_ACTION", .replacement=US"y" };
static macro_item p485 = { .next=&p484, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_OPT_TRANSPORTS_GROUP", .replacement=US"y" };
static macro_item p486 = { .next=&p485, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORTS_HEADERS_ADD", .replacement=US"y" };
static macro_item p487 = { .next=&p486, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORTS_HEADERS_ONLY", .replacement=US"y" };
static macro_item p488 = { .next=&p487, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORTS_HEADERS_REMOVE", .replacement=US"y" };
static macro_item p489 = { .next=&p488, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORTS_HEADERS_REWRITE", .replacement=US"y" };
static macro_item p490 = { .next=&p489, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORTS_HOME_DIRECTORY", .replacement=US"y" };
static macro_item p491 = { .next=&p490, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_TRANSPORTS_INITGROUPS", .replacement=US"y" };
static macro_item p492 = { .next=&p491, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORTS_MAX_PARALLEL", .replacement=US"y" };
static macro_item p493 = { .next=&p492, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORTS_MESSAGE_SIZE_LIMIT", .replacement=US"y" };
static macro_item p494 = { .next=&p493, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORTS_RCPT_INCLUDE_AFFIXES", .replacement=US"y" };
static macro_item p495 = { .next=&p494, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORTS_RETRY_USE_LOCAL_PART", .replacement=US"y" };
static macro_item p496 = { .next=&p495, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORTS_RETURN_PATH", .replacement=US"y" };
static macro_item p497 = { .next=&p496, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORTS_RETURN_PATH_ADD", .replacement=US"y" };
static macro_item p498 = { .next=&p497, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORTS_SHADOW_CONDITION", .replacement=US"y" };
static macro_item p499 = { .next=&p498, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORTS_SHADOW_TRANSPORT", .replacement=US"y" };
static macro_item p500 = { .next=&p499, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORTS_TRANSPORT_FILTER", .replacement=US"y" };
static macro_item p501 = { .next=&p500, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORTS_TRANSPORT_FILTER_TIMEOUT", .replacement=US"y" };
static macro_item p502 = { .next=&p501, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_OPT_TRANSPORTS_USER", .replacement=US"y" };
static macro_item p503 = { .next=&p502, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_DRIVER_TRANSPORT_SMTP", .replacement=US"y" };
static macro_item p504 = { .next=&p503, .command_line=FALSE, .namelen=48, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_ADDRESS_RETRY_INCLUDE_SENDER", .replacement=US"y" };
static macro_item p505 = { .next=&p504, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_ALLOW_LOCALHOST", .replacement=US"y" };
static macro_item p506 = { .next=&p505, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_AUTHENTICATED_SENDER", .replacement=US"y" };
static macro_item p507 = { .next=&p506, .command_line=FALSE, .namelen=46, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_AUTHENTICATED_SENDER_FORCE", .replacement=US"y" };
static macro_item p508 = { .next=&p507, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_COMMAND_TIMEOUT", .replacement=US"y" };
static macro_item p509 = { .next=&p508, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_CONNECT_TIMEOUT", .replacement=US"y" };
static macro_item p510 = { .next=&p509, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_CONNECTION_MAX_MESSAGES", .replacement=US"y" };
static macro_item p511 = { .next=&p510, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DANE_REQUIRE_TLS_CIPHERS", .replacement=US"y" };
static macro_item p512 = { .next=&p511, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DATA_TIMEOUT", .replacement=US"y" };
static macro_item p513 = { .next=&p512, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DELAY_AFTER_CUTOFF", .replacement=US"y" };
static macro_item p514 = { .next=&p513, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_CANON", .replacement=US"y" };
static macro_item p515 = { .next=&p514, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_DOMAIN", .replacement=US"y" };
static macro_item p516 = { .next=&p515, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_HASH", .replacement=US"y" };
static macro_item p517 = { .next=&p516, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_IDENTITY", .replacement=US"y" };
static macro_item p518 = { .next=&p517, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_PRIVATE_KEY", .replacement=US"y" };
static macro_item p519 = { .next=&p518, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_SELECTOR", .replacement=US"y" };
static macro_item p520 = { .next=&p519, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_SIGN_HEADERS", .replacement=US"y" };
static macro_item p521 = { .next=&p520, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_STRICT", .replacement=US"y" };
static macro_item p522 = { .next=&p521, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DKIM_TIMESTAMPS", .replacement=US"y" };
static macro_item p523 = { .next=&p522, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DNS_QUALIFY_SINGLE", .replacement=US"y" };
static macro_item p524 = { .next=&p523, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DNS_SEARCH_PARENTS", .replacement=US"y" };
static macro_item p525 = { .next=&p524, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DNSSEC_REQUEST_DOMAINS", .replacement=US"y" };
static macro_item p526 = { .next=&p525, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DNSSEC_REQUIRE_DOMAINS", .replacement=US"y" };
static macro_item p527 = { .next=&p526, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_DSCP", .replacement=US"y" };
static macro_item p528 = { .next=&p527, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_FALLBACK_HOSTS", .replacement=US"y" };
static macro_item p529 = { .next=&p528, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_FINAL_TIMEOUT", .replacement=US"y" };
static macro_item p530 = { .next=&p529, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_GETHOSTBYNAME", .replacement=US"y" };
static macro_item p531 = { .next=&p530, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HELO_DATA", .replacement=US"y" };
static macro_item p532 = { .next=&p531, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOST_NAME_EXTRACT", .replacement=US"y" };
static macro_item p533 = { .next=&p532, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS", .replacement=US"y" };
static macro_item p534 = { .next=&p533, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_AVOID_ESMTP", .replacement=US"y" };
static macro_item p535 = { .next=&p534, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_AVOID_PIPELINING", .replacement=US"y" };
static macro_item p536 = { .next=&p535, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_AVOID_TLS", .replacement=US"y" };
static macro_item p537 = { .next=&p536, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_MAX_TRY", .replacement=US"y" };
static macro_item p538 = { .next=&p537, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_MAX_TRY_HARDLIMIT", .replacement=US"y" };
static macro_item p539 = { .next=&p538, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_NOPASS_TLS", .replacement=US"y" };
static macro_item p540 = { .next=&p539, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_NOPROXY_TLS", .replacement=US"y" };
static macro_item p541 = { .next=&p540, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_OVERRIDE", .replacement=US"y" };
static macro_item p542 = { .next=&p541, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_PIPE_CONNECT", .replacement=US"y" };
static macro_item p543 = { .next=&p542, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_RANDOMIZE", .replacement=US"y" };
static macro_item p544 = { .next=&p543, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUEST_OCSP", .replacement=US"y" };
static macro_item p545 = { .next=&p544, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUIRE_ALPN", .replacement=US"y" };
static macro_item p546 = { .next=&p545, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUIRE_AUTH", .replacement=US"y" };
static macro_item p547 = { .next=&p546, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUIRE_DANE", .replacement=US"y" };
static macro_item p548 = { .next=&p547, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUIRE_OCSP", .replacement=US"y" };
static macro_item p549 = { .next=&p548, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_REQUIRE_TLS", .replacement=US"y" };
static macro_item p550 = { .next=&p549, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_TRY_AUTH", .replacement=US"y" };
static macro_item p551 = { .next=&p550, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_TRY_CHUNKING", .replacement=US"y" };
static macro_item p552 = { .next=&p551, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_TRY_DANE", .replacement=US"y" };
static macro_item p553 = { .next=&p552, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_TRY_FASTOPEN", .replacement=US"y" };
static macro_item p554 = { .next=&p553, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_TRY_PRDR", .replacement=US"y" };
static macro_item p555 = { .next=&p554, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_HOSTS_VERIFY_AVOID_TLS", .replacement=US"y" };
static macro_item p556 = { .next=&p555, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_INTERFACE", .replacement=US"y" };
static macro_item p557 = { .next=&p556, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_KEEPALIVE", .replacement=US"y" };
static macro_item p558 = { .next=&p557, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_LMTP_IGNORE_QUOTA", .replacement=US"y" };
static macro_item p559 = { .next=&p558, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_MAX_RCPT", .replacement=US"y" };
static macro_item p560 = { .next=&p559, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_MESSAGE_LINELENGTH_LIMIT", .replacement=US"y" };
static macro_item p561 = { .next=&p560, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_MULTI_DOMAIN", .replacement=US"y" };
static macro_item p562 = { .next=&p561, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_PORT", .replacement=US"y" };
static macro_item p563 = { .next=&p562, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_PROTOCOL", .replacement=US"y" };
static macro_item p564 = { .next=&p563, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_RETRY_INCLUDE_IP_ADDRESS", .replacement=US"y" };
static macro_item p565 = { .next=&p564, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_SERIALIZE_HOSTS", .replacement=US"y" };
static macro_item p566 = { .next=&p565, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_SIZE_ADDITION", .replacement=US"y" };
static macro_item p567 = { .next=&p566, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_ALPN", .replacement=US"y" };
static macro_item p568 = { .next=&p567, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_CERTIFICATE", .replacement=US"y" };
static macro_item p569 = { .next=&p568, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_CRL", .replacement=US"y" };
static macro_item p570 = { .next=&p569, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_DH_MIN_BITS", .replacement=US"y" };
static macro_item p571 = { .next=&p570, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_PRIVATEKEY", .replacement=US"y" };
static macro_item p572 = { .next=&p571, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_REQUIRE_CIPHERS", .replacement=US"y" };
static macro_item p573 = { .next=&p572, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_RESUMPTION_HOSTS", .replacement=US"y" };
static macro_item p574 = { .next=&p573, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_SNI", .replacement=US"y" };
static macro_item p575 = { .next=&p574, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_TEMPFAIL_TRYCLEAR", .replacement=US"y" };
static macro_item p576 = { .next=&p575, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_TRY_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p577 = { .next=&p576, .command_line=FALSE, .namelen=45, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_VERIFY_CERT_HOSTNAMES", .replacement=US"y" };
static macro_item p578 = { .next=&p577, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_VERIFY_CERTIFICATES", .replacement=US"y" };
static macro_item p579 = { .next=&p578, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_TLS_VERIFY_HOSTS", .replacement=US"y" };
static macro_item p580 = { .next=&p579, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_SMTP_UTF8_DOWNCONVERT", .replacement=US"y" };
static macro_item p581 = { .next=&p580, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_DRIVER_TRANSPORT_PIPE", .replacement=US"y" };
static macro_item p582 = { .next=&p581, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_ALLOW_COMMANDS", .replacement=US"y" };
static macro_item p583 = { .next=&p582, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_BATCH_ID", .replacement=US"y" };
static macro_item p584 = { .next=&p583, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_BATCH_MAX", .replacement=US"y" };
static macro_item p585 = { .next=&p584, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_CHECK_STRING", .replacement=US"y" };
static macro_item p586 = { .next=&p585, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_COMMAND", .replacement=US"y" };
static macro_item p587 = { .next=&p586, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_ENVIRONMENT", .replacement=US"y" };
static macro_item p588 = { .next=&p587, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_ESCAPE_STRING", .replacement=US"y" };
static macro_item p589 = { .next=&p588, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_FORCE_COMMAND", .replacement=US"y" };
static macro_item p590 = { .next=&p589, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_FREEZE_EXEC_FAIL", .replacement=US"y" };
static macro_item p591 = { .next=&p590, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_FREEZE_SIGNAL", .replacement=US"y" };
static macro_item p592 = { .next=&p591, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_IGNORE_STATUS", .replacement=US"y" };
static macro_item p593 = { .next=&p592, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_LOG_DEFER_OUTPUT", .replacement=US"y" };
static macro_item p594 = { .next=&p593, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_LOG_FAIL_OUTPUT", .replacement=US"y" };
static macro_item p595 = { .next=&p594, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_LOG_OUTPUT", .replacement=US"y" };
static macro_item p596 = { .next=&p595, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_MAX_OUTPUT", .replacement=US"y" };
static macro_item p597 = { .next=&p596, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_MESSAGE_PREFIX", .replacement=US"y" };
static macro_item p598 = { .next=&p597, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_MESSAGE_SUFFIX", .replacement=US"y" };
static macro_item p599 = { .next=&p598, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_PATH", .replacement=US"y" };
static macro_item p600 = { .next=&p599, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_PERMIT_COREDUMP", .replacement=US"y" };
static macro_item p601 = { .next=&p600, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_PIPE_AS_CREATOR", .replacement=US"y" };
static macro_item p602 = { .next=&p601, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_RESTRICT_TO_PATH", .replacement=US"y" };
static macro_item p603 = { .next=&p602, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_RETURN_FAIL_OUTPUT", .replacement=US"y" };
static macro_item p604 = { .next=&p603, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_RETURN_OUTPUT", .replacement=US"y" };
static macro_item p605 = { .next=&p604, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_TEMP_ERRORS", .replacement=US"y" };
static macro_item p606 = { .next=&p605, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_TIMEOUT", .replacement=US"y" };
static macro_item p607 = { .next=&p606, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_TIMEOUT_DEFER", .replacement=US"y" };
static macro_item p608 = { .next=&p607, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_UMASK", .replacement=US"y" };
static macro_item p609 = { .next=&p608, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_USE_BSMTP", .replacement=US"y" };
static macro_item p610 = { .next=&p609, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_USE_CRLF", .replacement=US"y" };
static macro_item p611 = { .next=&p610, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_PIPE_USE_SHELL", .replacement=US"y" };
static macro_item p612 = { .next=&p611, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_DRIVER_TRANSPORT_LMTP", .replacement=US"y" };
static macro_item p613 = { .next=&p612, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_BATCH_ID", .replacement=US"y" };
static macro_item p614 = { .next=&p613, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_BATCH_MAX", .replacement=US"y" };
static macro_item p615 = { .next=&p614, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_COMMAND", .replacement=US"y" };
static macro_item p616 = { .next=&p615, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_IGNORE_QUOTA", .replacement=US"y" };
static macro_item p617 = { .next=&p616, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_SOCKET", .replacement=US"y" };
static macro_item p618 = { .next=&p617, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_LMTP_TIMEOUT", .replacement=US"y" };
static macro_item p619 = { .next=&p618, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_DRIVER_TRANSPORT_AUTOREPLY", .replacement=US"y" };
static macro_item p620 = { .next=&p619, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_BCC", .replacement=US"y" };
static macro_item p621 = { .next=&p620, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_CC", .replacement=US"y" };
static macro_item p622 = { .next=&p621, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_FILE", .replacement=US"y" };
static macro_item p623 = { .next=&p622, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_FILE_EXPAND", .replacement=US"y" };
static macro_item p624 = { .next=&p623, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_FILE_OPTIONAL", .replacement=US"y" };
static macro_item p625 = { .next=&p624, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_FROM", .replacement=US"y" };
static macro_item p626 = { .next=&p625, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_HEADERS", .replacement=US"y" };
static macro_item p627 = { .next=&p626, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_LOG", .replacement=US"y" };
static macro_item p628 = { .next=&p627, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_MODE", .replacement=US"y" };
static macro_item p629 = { .next=&p628, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_NEVER_MAIL", .replacement=US"y" };
static macro_item p630 = { .next=&p629, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_ONCE", .replacement=US"y" };
static macro_item p631 = { .next=&p630, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_ONCE_FILE_SIZE", .replacement=US"y" };
static macro_item p632 = { .next=&p631, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_ONCE_REPEAT", .replacement=US"y" };
static macro_item p633 = { .next=&p632, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_REPLY_TO", .replacement=US"y" };
static macro_item p634 = { .next=&p633, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_RETURN_MESSAGE", .replacement=US"y" };
static macro_item p635 = { .next=&p634, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_SUBJECT", .replacement=US"y" };
static macro_item p636 = { .next=&p635, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_TEXT", .replacement=US"y" };
static macro_item p637 = { .next=&p636, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_OPT_TRANSPORT_AUTOREPLY_TO", .replacement=US"y" };
static macro_item p638 = { .next=&p637, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_DRIVER_TRANSPORT_APPENDFILE", .replacement=US"y" };
static macro_item p639 = { .next=&p638, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_ALLOW_FIFO", .replacement=US"y" };
static macro_item p640 = { .next=&p639, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_ALLOW_SYMLINK", .replacement=US"y" };
static macro_item p641 = { .next=&p640, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_BATCH_ID", .replacement=US"y" };
static macro_item p642 = { .next=&p641, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_BATCH_MAX", .replacement=US"y" };
static macro_item p643 = { .next=&p642, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_CHECK_GROUP", .replacement=US"y" };
static macro_item p644 = { .next=&p643, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_CHECK_OWNER", .replacement=US"y" };
static macro_item p645 = { .next=&p644, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_CHECK_STRING", .replacement=US"y" };
static macro_item p646 = { .next=&p645, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_CREATE_DIRECTORY", .replacement=US"y" };
static macro_item p647 = { .next=&p646, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_CREATE_FILE", .replacement=US"y" };
static macro_item p648 = { .next=&p647, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_DIRECTORY", .replacement=US"y" };
static macro_item p649 = { .next=&p648, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_DIRECTORY_FILE", .replacement=US"y" };
static macro_item p650 = { .next=&p649, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_DIRECTORY_MODE", .replacement=US"y" };
static macro_item p651 = { .next=&p650, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_ESCAPE_STRING", .replacement=US"y" };
static macro_item p652 = { .next=&p651, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_FILE", .replacement=US"y" };
static macro_item p653 = { .next=&p652, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_FILE_FORMAT", .replacement=US"y" };
static macro_item p654 = { .next=&p653, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_FILE_MUST_EXIST", .replacement=US"y" };
static macro_item p655 = { .next=&p654, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCK_FCNTL_TIMEOUT", .replacement=US"y" };
static macro_item p656 = { .next=&p655, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCK_FLOCK_TIMEOUT", .replacement=US"y" };
static macro_item p657 = { .next=&p656, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCK_INTERVAL", .replacement=US"y" };
static macro_item p658 = { .next=&p657, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCK_RETRIES", .replacement=US"y" };
static macro_item p659 = { .next=&p658, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCKFILE_MODE", .replacement=US"y" };
static macro_item p660 = { .next=&p659, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_LOCKFILE_TIMEOUT", .replacement=US"y" };
static macro_item p661 = { .next=&p660, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILBOX_FILECOUNT", .replacement=US"y" };
static macro_item p662 = { .next=&p661, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILBOX_SIZE", .replacement=US"y" };
static macro_item p663 = { .next=&p662, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIR_FORMAT", .replacement=US"y" };
static macro_item p664 = { .next=&p663, .command_line=FALSE, .namelen=55, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIR_QUOTA_DIRECTORY_REGEX", .replacement=US"y" };
static macro_item p665 = { .next=&p664, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIR_RETRIES", .replacement=US"y" };
static macro_item p666 = { .next=&p665, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIR_TAG", .replacement=US"y" };
static macro_item p667 = { .next=&p666, .command_line=FALSE, .namelen=47, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIR_USE_SIZE_FILE", .replacement=US"y" };
static macro_item p668 = { .next=&p667, .command_line=FALSE, .namelen=52, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MAILDIRFOLDER_CREATE_REGEX", .replacement=US"y" };
static macro_item p669 = { .next=&p668, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MESSAGE_PREFIX", .replacement=US"y" };
static macro_item p670 = { .next=&p669, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MESSAGE_SUFFIX", .replacement=US"y" };
static macro_item p671 = { .next=&p670, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MODE", .replacement=US"y" };
static macro_item p672 = { .next=&p671, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_MODE_FAIL_NARROWER", .replacement=US"y" };
static macro_item p673 = { .next=&p672, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_NOTIFY_COMSAT", .replacement=US"y" };
static macro_item p674 = { .next=&p673, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA", .replacement=US"y" };
static macro_item p675 = { .next=&p674, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_DIRECTORY", .replacement=US"y" };
static macro_item p676 = { .next=&p675, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_FILECOUNT", .replacement=US"y" };
static macro_item p677 = { .next=&p676, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_IS_INCLUSIVE", .replacement=US"y" };
static macro_item p678 = { .next=&p677, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_SIZE_REGEX", .replacement=US"y" };
static macro_item p679 = { .next=&p678, .command_line=FALSE, .namelen=44, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_WARN_MESSAGE", .replacement=US"y" };
static macro_item p680 = { .next=&p679, .command_line=FALSE, .namelen=46, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_QUOTA_WARN_THRESHOLD", .replacement=US"y" };
static macro_item p681 = { .next=&p680, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_USE_BSMTP", .replacement=US"y" };
static macro_item p682 = { .next=&p681, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_USE_CRLF", .replacement=US"y" };
static macro_item p683 = { .next=&p682, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_USE_FCNTL_LOCK", .replacement=US"y" };
static macro_item p684 = { .next=&p683, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_USE_FLOCK_LOCK", .replacement=US"y" };
static macro_item p685 = { .next=&p684, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_TRANSPORT_APPENDFILE_USE_LOCKFILE", .replacement=US"y" };
static macro_item p686 = { .next=&p685, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATORS_CLIENT_CONDITION", .replacement=US"y" };
static macro_item p687 = { .next=&p686, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_AUTHENTICATORS_CLIENT_SET_ID", .replacement=US"y" };
static macro_item p688 = { .next=&p687, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_OPT_AUTHENTICATORS_DRIVER", .replacement=US"y" };
static macro_item p689 = { .next=&p688, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_AUTHENTICATORS_PUBLIC_NAME", .replacement=US"y" };
static macro_item p690 = { .next=&p689, .command_line=FALSE, .namelen=46, .replen=1, .name=US"_OPT_AUTHENTICATORS_SERVER_ADVERTISE_CONDITION", .replacement=US"y" };
static macro_item p691 = { .next=&p690, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATORS_SERVER_CONDITION", .replacement=US"y" };
static macro_item p692 = { .next=&p691, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_AUTHENTICATORS_SERVER_DEBUG_PRINT", .replacement=US"y" };
static macro_item p693 = { .next=&p692, .command_line=FALSE, .namelen=46, .replen=1, .name=US"_OPT_AUTHENTICATORS_SERVER_MAIL_AUTH_CONDITION", .replacement=US"y" };
static macro_item p694 = { .next=&p693, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_OPT_AUTHENTICATORS_SERVER_SET_ID", .replacement=US"y" };
static macro_item p695 = { .next=&p694, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_DRIVER_AUTHENTICATOR_TLS", .replacement=US"y" };
static macro_item p696 = { .next=&p695, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_AUTHENTICATOR_TLS_SERVER_PARAM", .replacement=US"y" };
static macro_item p697 = { .next=&p696, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATOR_TLS_SERVER_PARAM1", .replacement=US"y" };
static macro_item p698 = { .next=&p697, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATOR_TLS_SERVER_PARAM2", .replacement=US"y" };
static macro_item p699 = { .next=&p698, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATOR_TLS_SERVER_PARAM3", .replacement=US"y" };
static macro_item p700 = { .next=&p699, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_DRIVER_AUTHENTICATOR_SPA", .replacement=US"y" };
static macro_item p701 = { .next=&p700, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_AUTHENTICATOR_SPA_CLIENT_DOMAIN", .replacement=US"y" };
static macro_item p702 = { .next=&p701, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_AUTHENTICATOR_SPA_CLIENT_PASSWORD", .replacement=US"y" };
static macro_item p703 = { .next=&p702, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_AUTHENTICATOR_SPA_CLIENT_USERNAME", .replacement=US"y" };
static macro_item p704 = { .next=&p703, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_AUTHENTICATOR_SPA_SERVER_PASSWORD", .replacement=US"y" };
static macro_item p705 = { .next=&p704, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_DRIVER_AUTHENTICATOR_PLAINTEXT", .replacement=US"y" };
static macro_item p706 = { .next=&p705, .command_line=FALSE, .namelen=57, .replen=1, .name=US"_OPT_AUTHENTICATOR_PLAINTEXT_CLIENT_IGNORE_INVALID_BASE64", .replacement=US"y" };
static macro_item p707 = { .next=&p706, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_AUTHENTICATOR_PLAINTEXT_CLIENT_SEND", .replacement=US"y" };
static macro_item p708 = { .next=&p707, .command_line=FALSE, .namelen=43, .replen=1, .name=US"_OPT_AUTHENTICATOR_PLAINTEXT_SERVER_PROMPTS", .replacement=US"y" };
static macro_item p709 = { .next=&p708, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_DRIVER_AUTHENTICATOR_DOVECOT", .replacement=US"y" };
static macro_item p710 = { .next=&p709, .command_line=FALSE, .namelen=40, .replen=1, .name=US"_OPT_AUTHENTICATOR_DOVECOT_SERVER_SOCKET", .replacement=US"y" };
static macro_item p711 = { .next=&p710, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_DRIVER_AUTHENTICATOR_CRAM_MD5", .replacement=US"y" };
static macro_item p712 = { .next=&p711, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_AUTHENTICATOR_CRAM_MD5_CLIENT_NAME", .replacement=US"y" };
static macro_item p713 = { .next=&p712, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_AUTHENTICATOR_CRAM_MD5_CLIENT_SECRET", .replacement=US"y" };
static macro_item p714 = { .next=&p713, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_AUTHENTICATOR_CRAM_MD5_SERVER_SECRET", .replacement=US"y" };
static macro_item p715 = { .next=&p714, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_LOG_8BITMIME", .replacement=US"y" };
static macro_item p716 = { .next=&p715, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_LOG_ACL_WARN_SKIPPED", .replacement=US"y" };
static macro_item p717 = { .next=&p716, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_ADDRESS_REWRITE", .replacement=US"y" };
static macro_item p718 = { .next=&p717, .command_line=FALSE, .namelen=8, .replen=1, .name=US"_LOG_ALL", .replacement=US"y" };
static macro_item p719 = { .next=&p718, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_LOG_ALL_PARENTS", .replacement=US"y" };
static macro_item p720 = { .next=&p719, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_LOG_ARGUMENTS", .replacement=US"y" };
static macro_item p721 = { .next=&p720, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_CONNECTION_ID", .replacement=US"y" };
static macro_item p722 = { .next=&p721, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_LOG_CONNECTION_REJECT", .replacement=US"y" };
static macro_item p723 = { .next=&p722, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_LOG_DELAY_DELIVERY", .replacement=US"y" };
static macro_item p724 = { .next=&p723, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_LOG_DELIVER_TIME", .replacement=US"y" };
static macro_item p725 = { .next=&p724, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_DELIVERY_SIZE", .replacement=US"y" };
static macro_item p726 = { .next=&p725, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_LOG_DKIM", .replacement=US"y" };
static macro_item p727 = { .next=&p726, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_LOG_DKIM_VERBOSE", .replacement=US"y" };
static macro_item p728 = { .next=&p727, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_DNSLIST_DEFER", .replacement=US"y" };
static macro_item p729 = { .next=&p728, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_LOG_DNSSEC", .replacement=US"y" };
static macro_item p730 = { .next=&p729, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_LOG_ETRN", .replacement=US"y" };
static macro_item p731 = { .next=&p730, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_HOST_LOOKUP_FAILED", .replacement=US"y" };
static macro_item p732 = { .next=&p731, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_IDENT_TIMEOUT", .replacement=US"y" };
static macro_item p733 = { .next=&p732, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_INCOMING_INTERFACE", .replacement=US"y" };
static macro_item p734 = { .next=&p733, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_INCOMING_PORT", .replacement=US"y" };
static macro_item p735 = { .next=&p734, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_LOG_LOST_INCOMING_CONNECTION", .replacement=US"y" };
static macro_item p736 = { .next=&p735, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_LOG_MILLISEC", .replacement=US"y" };
static macro_item p737 = { .next=&p736, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_LOG_MSG_ID", .replacement=US"y" };
static macro_item p738 = { .next=&p737, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_LOG_MSG_ID_CREATED", .replacement=US"y" };
static macro_item p739 = { .next=&p738, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_OUTGOING_INTERFACE", .replacement=US"y" };
static macro_item p740 = { .next=&p739, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_OUTGOING_PORT", .replacement=US"y" };
static macro_item p741 = { .next=&p740, .command_line=FALSE, .namelen=8, .replen=1, .name=US"_LOG_PID", .replacement=US"y" };
static macro_item p742 = { .next=&p741, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_LOG_PIPELINING", .replacement=US"y" };
static macro_item p743 = { .next=&p742, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_PROTOCOL_DETAIL", .replacement=US"y" };
static macro_item p744 = { .next=&p743, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_LOG_QUEUE_RUN", .replacement=US"y" };
static macro_item p745 = { .next=&p744, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_LOG_QUEUE_TIME", .replacement=US"y" };
static macro_item p746 = { .next=&p745, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_LOG_QUEUE_TIME_EXCLUSIVE", .replacement=US"y" };
static macro_item p747 = { .next=&p746, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_QUEUE_TIME_OVERALL", .replacement=US"y" };
static macro_item p748 = { .next=&p747, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_LOG_RECEIVE_TIME", .replacement=US"y" };
static macro_item p749 = { .next=&p748, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_LOG_RECEIVED_RECIPIENTS", .replacement=US"y" };
static macro_item p750 = { .next=&p749, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_RECEIVED_SENDER", .replacement=US"y" };
static macro_item p751 = { .next=&p750, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_REJECTED_HEADER", .replacement=US"y" };
static macro_item p752 = { .next=&p751, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_LOG_REJECTED_HEADERS", .replacement=US"y" };
static macro_item p753 = { .next=&p752, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_LOG_RETRY_DEFER", .replacement=US"y" };
static macro_item p754 = { .next=&p753, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_LOG_RETURN_PATH_ON_DELIVERY", .replacement=US"y" };
static macro_item p755 = { .next=&p754, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_SENDER_ON_DELIVERY", .replacement=US"y" };
static macro_item p756 = { .next=&p755, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_LOG_SENDER_VERIFY_FAIL", .replacement=US"y" };
static macro_item p757 = { .next=&p756, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_LOG_SIZE_REJECT", .replacement=US"y" };
static macro_item p758 = { .next=&p757, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_SKIP_DELIVERY", .replacement=US"y" };
static macro_item p759 = { .next=&p758, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_LOG_SMTP_CONFIRMATION", .replacement=US"y" };
static macro_item p760 = { .next=&p759, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_SMTP_CONNECTION", .replacement=US"y" };
static macro_item p761 = { .next=&p760, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_LOG_SMTP_INCOMPLETE_TRANSACTION", .replacement=US"y" };
static macro_item p762 = { .next=&p761, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_LOG_SMTP_MAILAUTH", .replacement=US"y" };
static macro_item p763 = { .next=&p762, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_LOG_SMTP_NO_MAIL", .replacement=US"y" };
static macro_item p764 = { .next=&p763, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_LOG_SMTP_PROTOCOL_ERROR", .replacement=US"y" };
static macro_item p765 = { .next=&p764, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_LOG_SMTP_SYNTAX_ERROR", .replacement=US"y" };
static macro_item p766 = { .next=&p765, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_LOG_SUBJECT", .replacement=US"y" };
static macro_item p767 = { .next=&p766, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_LOG_TLS_CERTIFICATE_VERIFIED", .replacement=US"y" };
static macro_item p768 = { .next=&p767, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_LOG_TLS_CIPHER", .replacement=US"y" };
static macro_item p769 = { .next=&p768, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_LOG_TLS_ON_CONNECT", .replacement=US"y" };
static macro_item p770 = { .next=&p769, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_LOG_TLS_PEERDN", .replacement=US"y" };
static macro_item p771 = { .next=&p770, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_LOG_TLS_RESUMPTION", .replacement=US"y" };
static macro_item p772 = { .next=&p771, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_LOG_TLS_SNI", .replacement=US"y" };
static macro_item p773 = { .next=&p772, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_LOG_UNKNOWN_IN_LIST", .replacement=US"y" };
static macro_item p774 = { .next=&p773, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_OPT_OPENSSL_ALL_X", .replacement=US"y" };
static macro_item p775 = { .next=&p774, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_OPENSSL_ALLOW_NO_DHE_KEX_X", .replacement=US"y" };
static macro_item p776 = { .next=&p775, .command_line=FALSE, .namelen=48, .replen=1, .name=US"_OPT_OPENSSL_ALLOW_UNSAFE_LEGACY_RENEGOTIATION_X", .replacement=US"y" };
static macro_item p777 = { .next=&p776, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_OPENSSL_CIPHER_SERVER_PREFERENCE_X", .replacement=US"y" };
static macro_item p778 = { .next=&p777, .command_line=FALSE, .namelen=35, .replen=1, .name=US"_OPT_OPENSSL_CRYPTOPRO_TLSEXT_BUG_X", .replacement=US"y" };
static macro_item p779 = { .next=&p778, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_OPENSSL_DONT_INSERT_EMPTY_FRAGMENTS_X", .replacement=US"y" };
static macro_item p780 = { .next=&p779, .command_line=FALSE, .namelen=38, .replen=1, .name=US"_OPT_OPENSSL_ENABLE_MIDDLEBOX_COMPAT_X", .replacement=US"y" };
static macro_item p781 = { .next=&p780, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_OPENSSL_EPHEMERAL_RSA_X", .replacement=US"y" };
static macro_item p782 = { .next=&p781, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_OPENSSL_LEGACY_SERVER_CONNECT_X", .replacement=US"y" };
static macro_item p783 = { .next=&p782, .command_line=FALSE, .namelen=41, .replen=1, .name=US"_OPT_OPENSSL_MICROSOFT_BIG_SSLV3_BUFFER_X", .replacement=US"y" };
static macro_item p784 = { .next=&p783, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_OPENSSL_MICROSOFT_SESS_ID_BUG_X", .replacement=US"y" };
static macro_item p785 = { .next=&p784, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_OPENSSL_MSIE_SSLV2_RSA_PADDING_X", .replacement=US"y" };
static macro_item p786 = { .next=&p785, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_OPENSSL_NETSCAPE_CHALLENGE_BUG_X", .replacement=US"y" };
static macro_item p787 = { .next=&p786, .command_line=FALSE, .namelen=47, .replen=1, .name=US"_OPT_OPENSSL_NETSCAPE_REUSE_CIPHER_CHANGE_BUG_X", .replacement=US"y" };
static macro_item p788 = { .next=&p787, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_OPENSSL_NO_ANTI_REPLAY_X", .replacement=US"y" };
static macro_item p789 = { .next=&p788, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_OPENSSL_NO_COMPRESSION_X", .replacement=US"y" };
static macro_item p790 = { .next=&p789, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_OPT_OPENSSL_NO_ENCRYPT_THEN_MAC_X", .replacement=US"y" };
static macro_item p791 = { .next=&p790, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_OPENSSL_NO_RENEGOTIATION_X", .replacement=US"y" };
static macro_item p792 = { .next=&p791, .command_line=FALSE, .namelen=53, .replen=1, .name=US"_OPT_OPENSSL_NO_SESSION_RESUMPTION_ON_RENEGOTIATION_X", .replacement=US"y" };
static macro_item p793 = { .next=&p792, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_OPENSSL_NO_SSLV2_X", .replacement=US"y" };
static macro_item p794 = { .next=&p793, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_OPENSSL_NO_SSLV3_X", .replacement=US"y" };
static macro_item p795 = { .next=&p794, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_OPT_OPENSSL_NO_TICKET_X", .replacement=US"y" };
static macro_item p796 = { .next=&p795, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_OPT_OPENSSL_NO_TLSV1_X", .replacement=US"y" };
static macro_item p797 = { .next=&p796, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_OPENSSL_NO_TLSV1_1_X", .replacement=US"y" };
static macro_item p798 = { .next=&p797, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_OPENSSL_NO_TLSV1_2_X", .replacement=US"y" };
static macro_item p799 = { .next=&p798, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_OPENSSL_NO_TLSV1_3_X", .replacement=US"y" };
static macro_item p800 = { .next=&p799, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_OPT_OPENSSL_PRIORITIZE_CHACHA_X", .replacement=US"y" };
static macro_item p801 = { .next=&p800, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_OPT_OPENSSL_SAFARI_ECDHE_ECDSA_BUG_X", .replacement=US"y" };
static macro_item p802 = { .next=&p801, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_OPT_OPENSSL_SINGLE_DH_USE_X", .replacement=US"y" };
static macro_item p803 = { .next=&p802, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_OPT_OPENSSL_SINGLE_ECDH_USE_X", .replacement=US"y" };
static macro_item p804 = { .next=&p803, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_OPT_OPENSSL_SSLEAY_080_CLIENT_DH_BUG_X", .replacement=US"y" };
static macro_item p805 = { .next=&p804, .command_line=FALSE, .namelen=42, .replen=1, .name=US"_OPT_OPENSSL_SSLREF2_REUSE_CERT_TYPE_BUG_X", .replacement=US"y" };
static macro_item p806 = { .next=&p805, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_OPT_OPENSSL_TLS_BLOCK_PADDING_BUG_X", .replacement=US"y" };
static macro_item p807 = { .next=&p806, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_OPT_OPENSSL_TLS_D5_BUG_X", .replacement=US"y" };
static macro_item p808 = { .next=&p807, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_OPT_OPENSSL_TLS_ROLLBACK_BUG_X", .replacement=US"y" };
static macro_item p809 = { .next=&p808, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_OPT_OPENSSL_TLSEXT_PADDING_X", .replacement=US"y" };
static macro_item p810 = { .next=&p809, .command_line=FALSE, .namelen=14, .replen=531, .name=US"_RESUME_DECODE", .replacement=US"not requested or offered: 0x02 :client requested, no server ticket: 0x04 : 0x05 : 0x06 :client offered session, no server action: 0x08 :no client request: 0x0A :client requested new ticket, server provided: 0x0C :client offered session, not used: 0x0E :client offered session, server only provided new ticket: 0x10 :session resumed unasked: 0x12 :session resumed unasked: 0x14 : 0x15: 0x16 :session resumed: 0x18 :session resumed unasked: 0x1A :session resumed unasked: 0x1C :session resumed: 0x1E :session resumed, also new ticket" };
static macro_item p811 = { .next=&p810, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_HAVE_TLS1_3", .replacement=US"y" };
static macro_item p812 = { .next=&p811, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_HAVE_TLS_OCSP", .replacement=US"y" };
static macro_item p813 = { .next=&p812, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_HAVE_TLS_OCSP_LIST", .replacement=US"y" };
static macro_item p814 = { .next=&p813, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_HAVE_TLS_ALPN", .replacement=US"y" };
static macro_item p815 = { .next=&p814, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_ITEM_ACL", .replacement=US"y" };
static macro_item p816 = { .next=&p815, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_ITEM_AUTHRESULTS", .replacement=US"y" };
static macro_item p817 = { .next=&p816, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_ITEM_CERTEXTRACT", .replacement=US"y" };
static macro_item p818 = { .next=&p817, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_DLFUNC", .replacement=US"y" };
static macro_item p819 = { .next=&p818, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_ITEM_ENV", .replacement=US"y" };
static macro_item p820 = { .next=&p819, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_ITEM_EXTRACT", .replacement=US"y" };
static macro_item p821 = { .next=&p820, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_FILTER", .replacement=US"y" };
static macro_item p822 = { .next=&p821, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_ITEM_HASH", .replacement=US"y" };
static macro_item p823 = { .next=&p822, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_ITEM_HMAC", .replacement=US"y" };
static macro_item p824 = { .next=&p823, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_ITEM_IF", .replacement=US"y" };
static macro_item p825 = { .next=&p824, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_ITEM_IMAPFOLDER", .replacement=US"y" };
static macro_item p826 = { .next=&p825, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_LENGTH", .replacement=US"y" };
static macro_item p827 = { .next=&p826, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_ITEM_LISTEXTRACT", .replacement=US"y" };
static macro_item p828 = { .next=&p827, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_ITEM_LISTQUOTE", .replacement=US"y" };
static macro_item p829 = { .next=&p828, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_LOOKUP", .replacement=US"y" };
static macro_item p830 = { .next=&p829, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_ITEM_MAP", .replacement=US"y" };
static macro_item p831 = { .next=&p830, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_ITEM_NHASH", .replacement=US"y" };
static macro_item p832 = { .next=&p831, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_ITEM_PERL", .replacement=US"y" };
static macro_item p833 = { .next=&p832, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_ITEM_PRVS", .replacement=US"y" };
static macro_item p834 = { .next=&p833, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_ITEM_PRVSCHECK", .replacement=US"y" };
static macro_item p835 = { .next=&p834, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_ITEM_READFILE", .replacement=US"y" };
static macro_item p836 = { .next=&p835, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_ITEM_READSOCKET", .replacement=US"y" };
static macro_item p837 = { .next=&p836, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_REDUCE", .replacement=US"y" };
static macro_item p838 = { .next=&p837, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_ITEM_RUN", .replacement=US"y" };
static macro_item p839 = { .next=&p838, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_ITEM_SG", .replacement=US"y" };
static macro_item p840 = { .next=&p839, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_ITEM_SORT", .replacement=US"y" };
static macro_item p841 = { .next=&p840, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_ITEM_SUBSTR", .replacement=US"y" };
static macro_item p842 = { .next=&p841, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_ITEM_TR", .replacement=US"y" };
static macro_item p843 = { .next=&p842, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_FROM_UTF8", .replacement=US"y" };
static macro_item p844 = { .next=&p843, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_OP_LOCAL_PART", .replacement=US"y" };
static macro_item p845 = { .next=&p844, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_OP_QUOTE_LOCAL_PART", .replacement=US"y" };
static macro_item p846 = { .next=&p845, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_OP_REVERSE_IP", .replacement=US"y" };
static macro_item p847 = { .next=&p846, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_TIME_EVAL", .replacement=US"y" };
static macro_item p848 = { .next=&p847, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_OP_TIME_INTERVAL", .replacement=US"y" };
static macro_item p849 = { .next=&p848, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_EXP_OP_UTF8_DOMAIN_FROM_ALABEL", .replacement=US"y" };
static macro_item p850 = { .next=&p849, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_OP_UTF8_DOMAIN_TO_ALABEL", .replacement=US"y" };
static macro_item p851 = { .next=&p850, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_EXP_OP_UTF8_LOCALPART_FROM_ALABEL", .replacement=US"y" };
static macro_item p852 = { .next=&p851, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_EXP_OP_UTF8_LOCALPART_TO_ALABEL", .replacement=US"y" };
static macro_item p853 = { .next=&p852, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_ADDRESS", .replacement=US"y" };
static macro_item p854 = { .next=&p853, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_ADDRESSES", .replacement=US"y" };
static macro_item p855 = { .next=&p854, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_BASE32", .replacement=US"y" };
static macro_item p856 = { .next=&p855, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_BASE32D", .replacement=US"y" };
static macro_item p857 = { .next=&p856, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_BASE62", .replacement=US"y" };
static macro_item p858 = { .next=&p857, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_BASE62D", .replacement=US"y" };
static macro_item p859 = { .next=&p858, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_BASE64", .replacement=US"y" };
static macro_item p860 = { .next=&p859, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_BASE64D", .replacement=US"y" };
static macro_item p861 = { .next=&p860, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_DOMAIN", .replacement=US"y" };
static macro_item p862 = { .next=&p861, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_ESCAPE", .replacement=US"y" };
static macro_item p863 = { .next=&p862, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_OP_ESCAPE8BIT", .replacement=US"y" };
static macro_item p864 = { .next=&p863, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_EVAL", .replacement=US"y" };
static macro_item p865 = { .next=&p864, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_EVAL10", .replacement=US"y" };
static macro_item p866 = { .next=&p865, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_EXPAND", .replacement=US"y" };
static macro_item p867 = { .next=&p866, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_EXP_OP_H", .replacement=US"y" };
static macro_item p868 = { .next=&p867, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_HASH", .replacement=US"y" };
static macro_item p869 = { .next=&p868, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_OP_HEADERWRAP", .replacement=US"y" };
static macro_item p870 = { .next=&p869, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_HEX2B64", .replacement=US"y" };
static macro_item p871 = { .next=&p870, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_OP_HEXQUOTE", .replacement=US"y" };
static macro_item p872 = { .next=&p871, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_OP_IPV6DENORM", .replacement=US"y" };
static macro_item p873 = { .next=&p872, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_OP_IPV6NORM", .replacement=US"y" };
static macro_item p874 = { .next=&p873, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_EXP_OP_L", .replacement=US"y" };
static macro_item p875 = { .next=&p874, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_EXP_OP_LC", .replacement=US"y" };
static macro_item p876 = { .next=&p875, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_LENGTH", .replacement=US"y" };
static macro_item p877 = { .next=&p876, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_LISTCOUNT", .replacement=US"y" };
static macro_item p878 = { .next=&p877, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_LISTNAMED", .replacement=US"y" };
static macro_item p879 = { .next=&p878, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_MASK", .replacement=US"y" };
static macro_item p880 = { .next=&p879, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_OP_MD5", .replacement=US"y" };
static macro_item p881 = { .next=&p880, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_EXP_OP_NH", .replacement=US"y" };
static macro_item p882 = { .next=&p881, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_OP_NHASH", .replacement=US"y" };
static macro_item p883 = { .next=&p882, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_OP_QUOTE", .replacement=US"y" };
static macro_item p884 = { .next=&p883, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_RANDINT", .replacement=US"y" };
static macro_item p885 = { .next=&p884, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_RFC2047", .replacement=US"y" };
static macro_item p886 = { .next=&p885, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_OP_RFC2047D", .replacement=US"y" };
static macro_item p887 = { .next=&p886, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_RXQUOTE", .replacement=US"y" };
static macro_item p888 = { .next=&p887, .command_line=FALSE, .namelen=9, .replen=1, .name=US"_EXP_OP_S", .replacement=US"y" };
static macro_item p889 = { .next=&p888, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_SHA1", .replacement=US"y" };
static macro_item p890 = { .next=&p889, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_SHA2", .replacement=US"y" };
static macro_item p891 = { .next=&p890, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_SHA256", .replacement=US"y" };
static macro_item p892 = { .next=&p891, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_SHA3", .replacement=US"y" };
static macro_item p893 = { .next=&p892, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_OP_STAT", .replacement=US"y" };
static macro_item p894 = { .next=&p893, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_OP_STR2B64", .replacement=US"y" };
static macro_item p895 = { .next=&p894, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_STRLEN", .replacement=US"y" };
static macro_item p896 = { .next=&p895, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_SUBSTR", .replacement=US"y" };
static macro_item p897 = { .next=&p896, .command_line=FALSE, .namelen=10, .replen=1, .name=US"_EXP_OP_UC", .replacement=US"y" };
static macro_item p898 = { .next=&p897, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_OP_UTF8CLEAN", .replacement=US"y" };
static macro_item p899 = { .next=&p898, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_OP_XTEXTD", .replacement=US"y" };
static macro_item p900 = { .next=&p899, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_COND_<", .replacement=US"y" };
static macro_item p901 = { .next=&p900, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_<=", .replacement=US"y" };
static macro_item p902 = { .next=&p901, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_COND_=", .replacement=US"y" };
static macro_item p903 = { .next=&p902, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_==", .replacement=US"y" };
static macro_item p904 = { .next=&p903, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_COND_>", .replacement=US"y" };
static macro_item p905 = { .next=&p904, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_>=", .replacement=US"y" };
static macro_item p906 = { .next=&p905, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_ACL", .replacement=US"y" };
static macro_item p907 = { .next=&p906, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_AND", .replacement=US"y" };
static macro_item p908 = { .next=&p907, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_COND_BOOL", .replacement=US"y" };
static macro_item p909 = { .next=&p908, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_COND_BOOL_LAX", .replacement=US"y" };
static macro_item p910 = { .next=&p909, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_COND_CRYPTEQ", .replacement=US"y" };
static macro_item p911 = { .next=&p910, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_DEF", .replacement=US"y" };
static macro_item p912 = { .next=&p911, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_EQ", .replacement=US"y" };
static macro_item p913 = { .next=&p912, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_EQI", .replacement=US"y" };
static macro_item p914 = { .next=&p913, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_COND_EXISTS", .replacement=US"y" };
static macro_item p915 = { .next=&p914, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_COND_FIRST_DELIVERY", .replacement=US"y" };
static macro_item p916 = { .next=&p915, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_COND_FORALL", .replacement=US"y" };
static macro_item p917 = { .next=&p916, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_COND_FORALL_JSON", .replacement=US"y" };
static macro_item p918 = { .next=&p917, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_COND_FORALL_JSONS", .replacement=US"y" };
static macro_item p919 = { .next=&p918, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_COND_FORANY", .replacement=US"y" };
static macro_item p920 = { .next=&p919, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_COND_FORANY_JSON", .replacement=US"y" };
static macro_item p921 = { .next=&p920, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_COND_FORANY_JSONS", .replacement=US"y" };
static macro_item p922 = { .next=&p921, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_GE", .replacement=US"y" };
static macro_item p923 = { .next=&p922, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_GEI", .replacement=US"y" };
static macro_item p924 = { .next=&p923, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_GT", .replacement=US"y" };
static macro_item p925 = { .next=&p924, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_GTI", .replacement=US"y" };
static macro_item p926 = { .next=&p925, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_COND_INLIST", .replacement=US"y" };
static macro_item p927 = { .next=&p926, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_COND_INLISTI", .replacement=US"y" };
static macro_item p928 = { .next=&p927, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_COND_ISIP", .replacement=US"y" };
static macro_item p929 = { .next=&p928, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_COND_ISIP4", .replacement=US"y" };
static macro_item p930 = { .next=&p929, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_COND_ISIP6", .replacement=US"y" };
static macro_item p931 = { .next=&p930, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_COND_LDAPAUTH", .replacement=US"y" };
static macro_item p932 = { .next=&p931, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_LE", .replacement=US"y" };
static macro_item p933 = { .next=&p932, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_LEI", .replacement=US"y" };
static macro_item p934 = { .next=&p933, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_LT", .replacement=US"y" };
static macro_item p935 = { .next=&p934, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_LTI", .replacement=US"y" };
static macro_item p936 = { .next=&p935, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_COND_MATCH", .replacement=US"y" };
static macro_item p937 = { .next=&p936, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_COND_MATCH_ADDRESS", .replacement=US"y" };
static macro_item p938 = { .next=&p937, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_COND_MATCH_DOMAIN", .replacement=US"y" };
static macro_item p939 = { .next=&p938, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_COND_MATCH_IP", .replacement=US"y" };
static macro_item p940 = { .next=&p939, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_COND_MATCH_LOCAL_PART", .replacement=US"y" };
static macro_item p941 = { .next=&p940, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_COND_OR", .replacement=US"y" };
static macro_item p942 = { .next=&p941, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_COND_PAM", .replacement=US"y" };
static macro_item p943 = { .next=&p942, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_COND_PWCHECK", .replacement=US"y" };
static macro_item p944 = { .next=&p943, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_COND_QUEUE_RUNNING", .replacement=US"y" };
static macro_item p945 = { .next=&p944, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_COND_RADIUS", .replacement=US"y" };
static macro_item p946 = { .next=&p945, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_COND_SASLAUTHD", .replacement=US"y" };
static macro_item p947 = { .next=&p946, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG1", .replacement=US"y" };
static macro_item p948 = { .next=&p947, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG2", .replacement=US"y" };
static macro_item p949 = { .next=&p948, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG3", .replacement=US"y" };
static macro_item p950 = { .next=&p949, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG4", .replacement=US"y" };
static macro_item p951 = { .next=&p950, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG5", .replacement=US"y" };
static macro_item p952 = { .next=&p951, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG6", .replacement=US"y" };
static macro_item p953 = { .next=&p952, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG7", .replacement=US"y" };
static macro_item p954 = { .next=&p953, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG8", .replacement=US"y" };
static macro_item p955 = { .next=&p954, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_ARG9", .replacement=US"y" };
static macro_item p956 = { .next=&p955, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_ACL_NARG", .replacement=US"y" };
static macro_item p957 = { .next=&p956, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_ACL_VERIFY_MESSAGE", .replacement=US"y" };
static macro_item p958 = { .next=&p957, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_ADDRESS_DATA", .replacement=US"y" };
static macro_item p959 = { .next=&p958, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_ADDRESS_FILE", .replacement=US"y" };
static macro_item p960 = { .next=&p959, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_ADDRESS_PIPE", .replacement=US"y" };
static macro_item p961 = { .next=&p960, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_ATRN_HOST", .replacement=US"y" };
static macro_item p962 = { .next=&p961, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_ATRN_MODE", .replacement=US"y" };
static macro_item p963 = { .next=&p962, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_AUTHENTICATED_FAIL_ID", .replacement=US"y" };
static macro_item p964 = { .next=&p963, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_AUTHENTICATED_ID", .replacement=US"y" };
static macro_item p965 = { .next=&p964, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_AUTHENTICATED_SENDER", .replacement=US"y" };
static macro_item p966 = { .next=&p965, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_AUTHENTICATION_FAILED", .replacement=US"y" };
static macro_item p967 = { .next=&p966, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_AV_FAILED", .replacement=US"y" };
static macro_item p968 = { .next=&p967, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_BODY_LINECOUNT", .replacement=US"y" };
static macro_item p969 = { .next=&p968, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_BODY_ZEROCOUNT", .replacement=US"y" };
static macro_item p970 = { .next=&p969, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_BOUNCE_RECIPIENT", .replacement=US"y" };
static macro_item p971 = { .next=&p970, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_EXP_VAR_BOUNCE_RETURN_SIZE_LIMIT", .replacement=US"y" };
static macro_item p972 = { .next=&p971, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_CALLER_GID", .replacement=US"y" };
static macro_item p973 = { .next=&p972, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_CALLER_UID", .replacement=US"y" };
static macro_item p974 = { .next=&p973, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_CALLOUT_ADDRESS", .replacement=US"y" };
static macro_item p975 = { .next=&p974, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_COMPILE_DATE", .replacement=US"y" };
static macro_item p976 = { .next=&p975, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_COMPILE_NUMBER", .replacement=US"y" };
static macro_item p977 = { .next=&p976, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_CONFIG_DIR", .replacement=US"y" };
static macro_item p978 = { .next=&p977, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_CONFIG_FILE", .replacement=US"y" };
static macro_item p979 = { .next=&p978, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_CONNECTION_ID", .replacement=US"y" };
static macro_item p980 = { .next=&p979, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_CSA_STATUS", .replacement=US"y" };
static macro_item p981 = { .next=&p980, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_DKIM_ALGO", .replacement=US"y" };
static macro_item p982 = { .next=&p981, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_DKIM_BODYLENGTH", .replacement=US"y" };
static macro_item p983 = { .next=&p982, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_DKIM_CANON_BODY", .replacement=US"y" };
static macro_item p984 = { .next=&p983, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_DKIM_CANON_HEADERS", .replacement=US"y" };
static macro_item p985 = { .next=&p984, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_DKIM_COPIEDHEADERS", .replacement=US"y" };
static macro_item p986 = { .next=&p985, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_DKIM_CREATED", .replacement=US"y" };
static macro_item p987 = { .next=&p986, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_DKIM_CUR_SIGNER", .replacement=US"y" };
static macro_item p988 = { .next=&p987, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_DKIM_DOMAIN", .replacement=US"y" };
static macro_item p989 = { .next=&p988, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_DKIM_EXPIRES", .replacement=US"y" };
static macro_item p990 = { .next=&p989, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_DKIM_HEADERNAMES", .replacement=US"y" };
static macro_item p991 = { .next=&p990, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_DKIM_IDENTITY", .replacement=US"y" };
static macro_item p992 = { .next=&p991, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_GRANULARITY", .replacement=US"y" };
static macro_item p993 = { .next=&p992, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_LENGTH", .replacement=US"y" };
static macro_item p994 = { .next=&p993, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_NOSUBDOMAINS", .replacement=US"y" };
static macro_item p995 = { .next=&p994, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_NOTES", .replacement=US"y" };
static macro_item p996 = { .next=&p995, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_SRVTYPE", .replacement=US"y" };
static macro_item p997 = { .next=&p996, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_DKIM_KEY_TESTING", .replacement=US"y" };
static macro_item p998 = { .next=&p997, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_DKIM_SELECTOR", .replacement=US"y" };
static macro_item p999 = { .next=&p998, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_DKIM_SIGNERS", .replacement=US"y" };
static macro_item p1000 = { .next=&p999, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_DKIM_VERIFY_REASON", .replacement=US"y" };
static macro_item p1001 = { .next=&p1000, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_DKIM_VERIFY_SIGNERS", .replacement=US"y" };
static macro_item p1002 = { .next=&p1001, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_DKIM_VERIFY_STATUS", .replacement=US"y" };
static macro_item p1003 = { .next=&p1002, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_DNSLIST_DOMAIN", .replacement=US"y" };
static macro_item p1004 = { .next=&p1003, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_DNSLIST_MATCHED", .replacement=US"y" };
static macro_item p1005 = { .next=&p1004, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_DNSLIST_TEXT", .replacement=US"y" };
static macro_item p1006 = { .next=&p1005, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_DNSLIST_VALUE", .replacement=US"y" };
static macro_item p1007 = { .next=&p1006, .command_line=FALSE, .namelen=15, .replen=1, .name=US"_EXP_VAR_DOMAIN", .replacement=US"y" };
static macro_item p1008 = { .next=&p1007, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_DOMAIN_DATA", .replacement=US"y" };
static macro_item p1009 = { .next=&p1008, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_EVENT_DATA", .replacement=US"y" };
static macro_item p1010 = { .next=&p1009, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_EVENT_DEFER_ERRNO", .replacement=US"y" };
static macro_item p1011 = { .next=&p1010, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_EVENT_NAME", .replacement=US"y" };
static macro_item p1012 = { .next=&p1011, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_EXIM_GID", .replacement=US"y" };
static macro_item p1013 = { .next=&p1012, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_EXIM_PATH", .replacement=US"y" };
static macro_item p1014 = { .next=&p1013, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_EXIM_UID", .replacement=US"y" };
static macro_item p1015 = { .next=&p1014, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_EXIM_VERSION", .replacement=US"y" };
static macro_item p1016 = { .next=&p1015, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_HEADERS_ADDED", .replacement=US"y" };
static macro_item p1017 = { .next=&p1016, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_VAR_HOME", .replacement=US"y" };
static macro_item p1018 = { .next=&p1017, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_VAR_HOST", .replacement=US"y" };
static macro_item p1019 = { .next=&p1018, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_HOST_ADDRESS", .replacement=US"y" };
static macro_item p1020 = { .next=&p1019, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_HOST_DATA", .replacement=US"y" };
static macro_item p1021 = { .next=&p1020, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_HOST_LOOKUP_DEFERRED", .replacement=US"y" };
static macro_item p1022 = { .next=&p1021, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_HOST_LOOKUP_FAILED", .replacement=US"y" };
static macro_item p1023 = { .next=&p1022, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_HOST_PORT", .replacement=US"y" };
static macro_item p1024 = { .next=&p1023, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_INITIAL_CWD", .replacement=US"y" };
static macro_item p1025 = { .next=&p1024, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_VAR_INODE", .replacement=US"y" };
static macro_item p1026 = { .next=&p1025, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_INTERFACE_ADDRESS", .replacement=US"y" };
static macro_item p1027 = { .next=&p1026, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_INTERFACE_PORT", .replacement=US"y" };
static macro_item p1028 = { .next=&p1027, .command_line=FALSE, .namelen=13, .replen=1, .name=US"_EXP_VAR_ITEM", .replacement=US"y" };
static macro_item p1029 = { .next=&p1028, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_VAR_LDAP_DN", .replacement=US"y" };
static macro_item p1030 = { .next=&p1029, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_LOAD_AVERAGE", .replacement=US"y" };
static macro_item p1031 = { .next=&p1030, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_LOCAL_PART", .replacement=US"y" };
static macro_item p1032 = { .next=&p1031, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_LOCAL_PART_DATA", .replacement=US"y" };
static macro_item p1033 = { .next=&p1032, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_LOCAL_PART_PREFIX", .replacement=US"y" };
static macro_item p1034 = { .next=&p1033, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_LOCAL_PART_PREFIX_V", .replacement=US"y" };
static macro_item p1035 = { .next=&p1034, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_LOCAL_PART_SUFFIX", .replacement=US"y" };
static macro_item p1036 = { .next=&p1035, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_LOCAL_PART_SUFFIX_V", .replacement=US"y" };
static macro_item p1037 = { .next=&p1036, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_LOCAL_USER_GID", .replacement=US"y" };
static macro_item p1038 = { .next=&p1037, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_LOCAL_USER_UID", .replacement=US"y" };
static macro_item p1039 = { .next=&p1038, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_LOCALHOST_NUMBER", .replacement=US"y" };
static macro_item p1040 = { .next=&p1039, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_LOG_INODES", .replacement=US"y" };
static macro_item p1041 = { .next=&p1040, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_LOG_SPACE", .replacement=US"y" };
static macro_item p1042 = { .next=&p1041, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_EXP_VAR_LOOKUP_DNSSEC_AUTHENTICATED", .replacement=US"y" };
static macro_item p1043 = { .next=&p1042, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_MAILSTORE_BASENAME", .replacement=US"y" };
static macro_item p1044 = { .next=&p1043, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_MALWARE_NAME", .replacement=US"y" };
static macro_item p1045 = { .next=&p1044, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_EXP_VAR_MAX_RECEIVED_LINELENGTH", .replacement=US"y" };
static macro_item p1046 = { .next=&p1045, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_MESSAGE_AGE", .replacement=US"y" };
static macro_item p1047 = { .next=&p1046, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_MESSAGE_BODY", .replacement=US"y" };
static macro_item p1048 = { .next=&p1047, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_MESSAGE_BODY_END", .replacement=US"y" };
static macro_item p1049 = { .next=&p1048, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MESSAGE_BODY_SIZE", .replacement=US"y" };
static macro_item p1050 = { .next=&p1049, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_MESSAGE_EXIM_ID", .replacement=US"y" };
static macro_item p1051 = { .next=&p1050, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_MESSAGE_HEADERS", .replacement=US"y" };
static macro_item p1052 = { .next=&p1051, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_MESSAGE_HEADERS_RAW", .replacement=US"y" };
static macro_item p1053 = { .next=&p1052, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_MESSAGE_ID", .replacement=US"y" };
static macro_item p1054 = { .next=&p1053, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MESSAGE_LINECOUNT", .replacement=US"y" };
static macro_item p1055 = { .next=&p1054, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_MESSAGE_SIZE", .replacement=US"y" };
static macro_item p1056 = { .next=&p1055, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_MESSAGE_SMTPUTF8", .replacement=US"y" };
static macro_item p1057 = { .next=&p1056, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_MIME_ANOMALY_LEVEL", .replacement=US"y" };
static macro_item p1058 = { .next=&p1057, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MIME_ANOMALY_TEXT", .replacement=US"y" };
static macro_item p1059 = { .next=&p1058, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_MIME_BOUNDARY", .replacement=US"y" };
static macro_item p1060 = { .next=&p1059, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_MIME_CHARSET", .replacement=US"y" };
static macro_item p1061 = { .next=&p1060, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_DESCRIPTION", .replacement=US"y" };
static macro_item p1062 = { .next=&p1061, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_DISPOSITION", .replacement=US"y" };
static macro_item p1063 = { .next=&p1062, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_ID", .replacement=US"y" };
static macro_item p1064 = { .next=&p1063, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_SIZE", .replacement=US"y" };
static macro_item p1065 = { .next=&p1064, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_TRANSFER_ENCODING", .replacement=US"y" };
static macro_item p1066 = { .next=&p1065, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MIME_CONTENT_TYPE", .replacement=US"y" };
static macro_item p1067 = { .next=&p1066, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_MIME_DECODED_FILENAME", .replacement=US"y" };
static macro_item p1068 = { .next=&p1067, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_MIME_FILENAME", .replacement=US"y" };
static macro_item p1069 = { .next=&p1068, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_MIME_IS_COVERLETTER", .replacement=US"y" };
static macro_item p1070 = { .next=&p1069, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_MIME_IS_MULTIPART", .replacement=US"y" };
static macro_item p1071 = { .next=&p1070, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_MIME_IS_RFC822", .replacement=US"y" };
static macro_item p1072 = { .next=&p1071, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_MIME_PART_COUNT", .replacement=US"y" };
static macro_item p1073 = { .next=&p1072, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N0", .replacement=US"y" };
static macro_item p1074 = { .next=&p1073, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N1", .replacement=US"y" };
static macro_item p1075 = { .next=&p1074, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N2", .replacement=US"y" };
static macro_item p1076 = { .next=&p1075, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N3", .replacement=US"y" };
static macro_item p1077 = { .next=&p1076, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N4", .replacement=US"y" };
static macro_item p1078 = { .next=&p1077, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N5", .replacement=US"y" };
static macro_item p1079 = { .next=&p1078, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N6", .replacement=US"y" };
static macro_item p1080 = { .next=&p1079, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N7", .replacement=US"y" };
static macro_item p1081 = { .next=&p1080, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N8", .replacement=US"y" };
static macro_item p1082 = { .next=&p1081, .command_line=FALSE, .namelen=11, .replen=1, .name=US"_EXP_VAR_N9", .replacement=US"y" };
static macro_item p1083 = { .next=&p1082, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_ORIGINAL_DOMAIN", .replacement=US"y" };
static macro_item p1084 = { .next=&p1083, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_ORIGINAL_LOCAL_PART", .replacement=US"y" };
static macro_item p1085 = { .next=&p1084, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_ORIGINATOR_GID", .replacement=US"y" };
static macro_item p1086 = { .next=&p1085, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_ORIGINATOR_UID", .replacement=US"y" };
static macro_item p1087 = { .next=&p1086, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_PARENT_DOMAIN", .replacement=US"y" };
static macro_item p1088 = { .next=&p1087, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_PARENT_LOCAL_PART", .replacement=US"y" };
static macro_item p1089 = { .next=&p1088, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_PID", .replacement=US"y" };
static macro_item p1090 = { .next=&p1089, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_PRDR_REQUESTED", .replacement=US"y" };
static macro_item p1091 = { .next=&p1090, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_PRIMARY_HOSTNAME", .replacement=US"y" };
static macro_item p1092 = { .next=&p1091, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_PRVSCHECK_ADDRESS", .replacement=US"y" };
static macro_item p1093 = { .next=&p1092, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_PRVSCHECK_KEYNUM", .replacement=US"y" };
static macro_item p1094 = { .next=&p1093, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_PRVSCHECK_RESULT", .replacement=US"y" };
static macro_item p1095 = { .next=&p1094, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_QUALIFY_DOMAIN", .replacement=US"y" };
static macro_item p1096 = { .next=&p1095, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_QUALIFY_RECIPIENT", .replacement=US"y" };
static macro_item p1097 = { .next=&p1096, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_QUEUE_NAME", .replacement=US"y" };
static macro_item p1098 = { .next=&p1097, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_QUEUE_SIZE", .replacement=US"y" };
static macro_item p1099 = { .next=&p1098, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_RCPT_COUNT", .replacement=US"y" };
static macro_item p1100 = { .next=&p1099, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_RCPT_DEFER_COUNT", .replacement=US"y" };
static macro_item p1101 = { .next=&p1100, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_RCPT_FAIL_COUNT", .replacement=US"y" };
static macro_item p1102 = { .next=&p1101, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_RECEIVED_COUNT", .replacement=US"y" };
static macro_item p1103 = { .next=&p1102, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_RECEIVED_FOR", .replacement=US"y" };
static macro_item p1104 = { .next=&p1103, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_RECEIVED_IP_ADDRESS", .replacement=US"y" };
static macro_item p1105 = { .next=&p1104, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_RECEIVED_PORT", .replacement=US"y" };
static macro_item p1106 = { .next=&p1105, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_RECEIVED_PROTOCOL", .replacement=US"y" };
static macro_item p1107 = { .next=&p1106, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_RECEIVED_TIME", .replacement=US"y" };
static macro_item p1108 = { .next=&p1107, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_RECIPIENT_DATA", .replacement=US"y" };
static macro_item p1109 = { .next=&p1108, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_EXP_VAR_RECIPIENT_VERIFY_FAILURE", .replacement=US"y" };
static macro_item p1110 = { .next=&p1109, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_RECIPIENTS", .replacement=US"y" };
static macro_item p1111 = { .next=&p1110, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_RECIPIENTS_COUNT", .replacement=US"y" };
static macro_item p1112 = { .next=&p1111, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_RECIPIENTS_LIST", .replacement=US"y" };
static macro_item p1113 = { .next=&p1112, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_REGEX_CACHESIZE", .replacement=US"y" };
static macro_item p1114 = { .next=&p1113, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_REGEX_MATCH_STRING", .replacement=US"y" };
static macro_item p1115 = { .next=&p1114, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_REPLY_ADDRESS", .replacement=US"y" };
static macro_item p1116 = { .next=&p1115, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_RETURN_PATH", .replacement=US"y" };
static macro_item p1117 = { .next=&p1116, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_RETURN_SIZE_LIMIT", .replacement=US"y" };
static macro_item p1118 = { .next=&p1117, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_ROUTER_NAME", .replacement=US"y" };
static macro_item p1119 = { .next=&p1118, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_VAR_RUNRC", .replacement=US"y" };
static macro_item p1120 = { .next=&p1119, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_SELF_HOSTNAME", .replacement=US"y" };
static macro_item p1121 = { .next=&p1120, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_SENDER_ADDRESS", .replacement=US"y" };
static macro_item p1122 = { .next=&p1121, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_SENDER_ADDRESS_DATA", .replacement=US"y" };
static macro_item p1123 = { .next=&p1122, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_SENDER_ADDRESS_DOMAIN", .replacement=US"y" };
static macro_item p1124 = { .next=&p1123, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_EXP_VAR_SENDER_ADDRESS_LOCAL_PART", .replacement=US"y" };
static macro_item p1125 = { .next=&p1124, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_SENDER_DATA", .replacement=US"y" };
static macro_item p1126 = { .next=&p1125, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_SENDER_FULLHOST", .replacement=US"y" };
static macro_item p1127 = { .next=&p1126, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SENDER_HELO_DNSSEC", .replacement=US"y" };
static macro_item p1128 = { .next=&p1127, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_SENDER_HELO_NAME", .replacement=US"y" };
static macro_item p1129 = { .next=&p1128, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_SENDER_HELO_VERIFIED", .replacement=US"y" };
static macro_item p1130 = { .next=&p1129, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_SENDER_HOST_ADDRESS", .replacement=US"y" };
static macro_item p1131 = { .next=&p1130, .command_line=FALSE, .namelen=34, .replen=1, .name=US"_EXP_VAR_SENDER_HOST_AUTHENTICATED", .replacement=US"y" };
static macro_item p1132 = { .next=&p1131, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SENDER_HOST_DNSSEC", .replacement=US"y" };
static macro_item p1133 = { .next=&p1132, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_SENDER_HOST_NAME", .replacement=US"y" };
static macro_item p1134 = { .next=&p1133, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_SENDER_HOST_PORT", .replacement=US"y" };
static macro_item p1135 = { .next=&p1134, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_SENDER_IDENT", .replacement=US"y" };
static macro_item p1136 = { .next=&p1135, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_SENDER_RATE", .replacement=US"y" };
static macro_item p1137 = { .next=&p1136, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_SENDER_RATE_LIMIT", .replacement=US"y" };
static macro_item p1138 = { .next=&p1137, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SENDER_RATE_PERIOD", .replacement=US"y" };
static macro_item p1139 = { .next=&p1138, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_SENDER_RCVHOST", .replacement=US"y" };
static macro_item p1140 = { .next=&p1139, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_SENDER_VERIFY_FAILURE", .replacement=US"y" };
static macro_item p1141 = { .next=&p1140, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SENDING_IP_ADDRESS", .replacement=US"y" };
static macro_item p1142 = { .next=&p1141, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_SENDING_PORT", .replacement=US"y" };
static macro_item p1143 = { .next=&p1142, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_SMTP_ACTIVE_HOSTNAME", .replacement=US"y" };
static macro_item p1144 = { .next=&p1143, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_SMTP_COMMAND", .replacement=US"y" };
static macro_item p1145 = { .next=&p1144, .command_line=FALSE, .namelen=30, .replen=1, .name=US"_EXP_VAR_SMTP_COMMAND_ARGUMENT", .replacement=US"y" };
static macro_item p1146 = { .next=&p1145, .command_line=FALSE, .namelen=29, .replen=1, .name=US"_EXP_VAR_SMTP_COMMAND_HISTORY", .replacement=US"y" };
static macro_item p1147 = { .next=&p1146, .command_line=FALSE, .namelen=39, .replen=1, .name=US"_EXP_VAR_SMTP_COUNT_AT_CONNECTION_START", .replacement=US"y" };
static macro_item p1148 = { .next=&p1147, .command_line=FALSE, .namelen=28, .replen=1, .name=US"_EXP_VAR_SMTP_NOTQUIT_REASON", .replacement=US"y" };
static macro_item p1149 = { .next=&p1148, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN0", .replacement=US"y" };
static macro_item p1150 = { .next=&p1149, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN1", .replacement=US"y" };
static macro_item p1151 = { .next=&p1150, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN2", .replacement=US"y" };
static macro_item p1152 = { .next=&p1151, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN3", .replacement=US"y" };
static macro_item p1153 = { .next=&p1152, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN4", .replacement=US"y" };
static macro_item p1154 = { .next=&p1153, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN5", .replacement=US"y" };
static macro_item p1155 = { .next=&p1154, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN6", .replacement=US"y" };
static macro_item p1156 = { .next=&p1155, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN7", .replacement=US"y" };
static macro_item p1157 = { .next=&p1156, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN8", .replacement=US"y" };
static macro_item p1158 = { .next=&p1157, .command_line=FALSE, .namelen=12, .replen=1, .name=US"_EXP_VAR_SN9", .replacement=US"y" };
static macro_item p1159 = { .next=&p1158, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_SPAM_ACTION", .replacement=US"y" };
static macro_item p1160 = { .next=&p1159, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_SPAM_BAR", .replacement=US"y" };
static macro_item p1161 = { .next=&p1160, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_SPAM_REPORT", .replacement=US"y" };
static macro_item p1162 = { .next=&p1161, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_SPAM_SCORE", .replacement=US"y" };
static macro_item p1163 = { .next=&p1162, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_SPAM_SCORE_INT", .replacement=US"y" };
static macro_item p1164 = { .next=&p1163, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_SPF_GUESS", .replacement=US"y" };
static macro_item p1165 = { .next=&p1164, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SPF_HEADER_COMMENT", .replacement=US"y" };
static macro_item p1166 = { .next=&p1165, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_SPF_RECEIVED", .replacement=US"y" };
static macro_item p1167 = { .next=&p1166, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_SPF_RESULT", .replacement=US"y" };
static macro_item p1168 = { .next=&p1167, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_SPF_RESULT_GUESSED", .replacement=US"y" };
static macro_item p1169 = { .next=&p1168, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_SPF_SMTP_COMMENT", .replacement=US"y" };
static macro_item p1170 = { .next=&p1169, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_SPOOL_DIRECTORY", .replacement=US"y" };
static macro_item p1171 = { .next=&p1170, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_SPOOL_INODES", .replacement=US"y" };
static macro_item p1172 = { .next=&p1171, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_SPOOL_SPACE", .replacement=US"y" };
static macro_item p1173 = { .next=&p1172, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_THISADDRESS", .replacement=US"y" };
static macro_item p1174 = { .next=&p1173, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_TLS_BITS", .replacement=US"y" };
static macro_item p1175 = { .next=&p1174, .command_line=FALSE, .namelen=33, .replen=1, .name=US"_EXP_VAR_TLS_CERTIFICATE_VERIFIED", .replacement=US"y" };
static macro_item p1176 = { .next=&p1175, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_TLS_CIPHER", .replacement=US"y" };
static macro_item p1177 = { .next=&p1176, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TLS_IN_BITS", .replacement=US"y" };
static macro_item p1178 = { .next=&p1177, .command_line=FALSE, .namelen=36, .replen=1, .name=US"_EXP_VAR_TLS_IN_CERTIFICATE_VERIFIED", .replacement=US"y" };
static macro_item p1179 = { .next=&p1178, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_TLS_IN_CIPHER", .replacement=US"y" };
static macro_item p1180 = { .next=&p1179, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_TLS_IN_CIPHER_STD", .replacement=US"y" };
static macro_item p1181 = { .next=&p1180, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TLS_IN_OCSP", .replacement=US"y" };
static macro_item p1182 = { .next=&p1181, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_TLS_IN_OURCERT", .replacement=US"y" };
static macro_item p1183 = { .next=&p1182, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_TLS_IN_PEERCERT", .replacement=US"y" };
static macro_item p1184 = { .next=&p1183, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_TLS_IN_PEERDN", .replacement=US"y" };
static macro_item p1185 = { .next=&p1184, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_TLS_IN_RESUMPTION", .replacement=US"y" };
static macro_item p1186 = { .next=&p1185, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_TLS_IN_SNI", .replacement=US"y" };
static macro_item p1187 = { .next=&p1186, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_TLS_IN_VER", .replacement=US"y" };
static macro_item p1188 = { .next=&p1187, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_TLS_OUT_BITS", .replacement=US"y" };
static macro_item p1189 = { .next=&p1188, .command_line=FALSE, .namelen=37, .replen=1, .name=US"_EXP_VAR_TLS_OUT_CERTIFICATE_VERIFIED", .replacement=US"y" };
static macro_item p1190 = { .next=&p1189, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_TLS_OUT_CIPHER", .replacement=US"y" };
static macro_item p1191 = { .next=&p1190, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_TLS_OUT_CIPHER_STD", .replacement=US"y" };
static macro_item p1192 = { .next=&p1191, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_TLS_OUT_DANE", .replacement=US"y" };
static macro_item p1193 = { .next=&p1192, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_TLS_OUT_OCSP", .replacement=US"y" };
static macro_item p1194 = { .next=&p1193, .command_line=FALSE, .namelen=24, .replen=1, .name=US"_EXP_VAR_TLS_OUT_OURCERT", .replacement=US"y" };
static macro_item p1195 = { .next=&p1194, .command_line=FALSE, .namelen=25, .replen=1, .name=US"_EXP_VAR_TLS_OUT_PEERCERT", .replacement=US"y" };
static macro_item p1196 = { .next=&p1195, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_TLS_OUT_PEERDN", .replacement=US"y" };
static macro_item p1197 = { .next=&p1196, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_TLS_OUT_RESUMPTION", .replacement=US"y" };
static macro_item p1198 = { .next=&p1197, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TLS_OUT_SNI", .replacement=US"y" };
static macro_item p1199 = { .next=&p1198, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_TLS_OUT_TLSA_USAGE", .replacement=US"y" };
static macro_item p1200 = { .next=&p1199, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TLS_OUT_VER", .replacement=US"y" };
static macro_item p1201 = { .next=&p1200, .command_line=FALSE, .namelen=19, .replen=1, .name=US"_EXP_VAR_TLS_PEERDN", .replacement=US"y" };
static macro_item p1202 = { .next=&p1201, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_VAR_TLS_SNI", .replacement=US"y" };
static macro_item p1203 = { .next=&p1202, .command_line=FALSE, .namelen=21, .replen=1, .name=US"_EXP_VAR_TOD_BSDINBOX", .replacement=US"y" };
static macro_item p1204 = { .next=&p1203, .command_line=FALSE, .namelen=18, .replen=1, .name=US"_EXP_VAR_TOD_EPOCH", .replacement=US"y" };
static macro_item p1205 = { .next=&p1204, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TOD_EPOCH_L", .replacement=US"y" };
static macro_item p1206 = { .next=&p1205, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_TOD_FULL", .replacement=US"y" };
static macro_item p1207 = { .next=&p1206, .command_line=FALSE, .namelen=16, .replen=1, .name=US"_EXP_VAR_TOD_LOG", .replacement=US"y" };
static macro_item p1208 = { .next=&p1207, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_TOD_LOGFILE", .replacement=US"y" };
static macro_item p1209 = { .next=&p1208, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_TOD_ZONE", .replacement=US"y" };
static macro_item p1210 = { .next=&p1209, .command_line=FALSE, .namelen=17, .replen=1, .name=US"_EXP_VAR_TOD_ZULU", .replacement=US"y" };
static macro_item p1211 = { .next=&p1210, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_TRANSPORT_NAME", .replacement=US"y" };
static macro_item p1212 = { .next=&p1211, .command_line=FALSE, .namelen=14, .replen=1, .name=US"_EXP_VAR_VALUE", .replacement=US"y" };
static macro_item p1213 = { .next=&p1212, .command_line=FALSE, .namelen=20, .replen=1, .name=US"_EXP_VAR_VERIFY_MODE", .replacement=US"y" };
static macro_item p1214 = { .next=&p1213, .command_line=FALSE, .namelen=23, .replen=1, .name=US"_EXP_VAR_VERSION_NUMBER", .replacement=US"y" };
static macro_item p1215 = { .next=&p1214, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_WARN_MESSAGE_DELAY", .replacement=US"y" };
static macro_item p1216 = { .next=&p1215, .command_line=FALSE, .namelen=31, .replen=1, .name=US"_EXP_VAR_WARN_MESSAGE_RECIPIENT", .replacement=US"y" };
static macro_item p1217 = { .next=&p1216, .command_line=FALSE, .namelen=32, .replen=1, .name=US"_EXP_VAR_WARN_MESSAGE_RECIPIENTS", .replacement=US"y" };
static macro_item p1218 = { .next=&p1217, .command_line=FALSE, .namelen=22, .replen=1, .name=US"_EXP_VAR_WARNMSG_DELAY", .replacement=US"y" };
static macro_item p1219 = { .next=&p1218, .command_line=FALSE, .namelen=26, .replen=1, .name=US"_EXP_VAR_WARNMSG_RECIPIENT", .replacement=US"y" };
static macro_item p1220 = { .next=&p1219, .command_line=FALSE, .namelen=27, .replen=1, .name=US"_EXP_VAR_WARNMSG_RECIPIENTS", .replacement=US"y" };
static macro_item p1221 = { .next=&p1220, .command_line=FALSE, .namelen=18, .replen=316, .name=US"_DKIM_SIGN_HEADERS", .replacement=US"From:Sender:Reply-To:Subject:Date:Message-ID:To:Cc:MIME-Version:Content-Type:Content-Transfer-Encoding:Content-ID:Content-Description:Resent-Date:Resent-From:Resent-Sender:Resent-To:Resent-Cc:Resent-Message-ID:In-Reply-To:References:List-Id:List-Help:List-Unsubscribe:List-Subscribe:List-Post:List-Owner:List-Archive" };
static macro_item p1222 = { .next=&p1221, .command_line=FALSE, .namelen=22, .replen=344, .name=US"_DKIM_OVERSIGN_HEADERS", .replacement=US"+From:+Sender:+Reply-To:+Subject:+Date:+Message-ID:+To:+Cc:+MIME-Version:+Content-Type:+Content-Transfer-Encoding:+Content-ID:+Content-Description:+Resent-Date:+Resent-From:+Resent-Sender:+Resent-To:+Resent-Cc:+Resent-Message-ID:+In-Reply-To:+References:+List-Id:+List-Help:+List-Unsubscribe:+List-Subscribe:+List-Post:+List-Owner:+List-Archive" };
macro_item * macros = &p1222;
macro_item * mlast = &p0;
